@@ -1,5 +1,4 @@
 /*
- * Copyright (C) Jan 2019 Mellanox Technologies Ltd. All rights reserved.
  * Copyright (c) 2012-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
@@ -30,6 +29,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  *
+ *  Version: $Id$
  */
 /*************************** Adb ***************************/
 #ifndef ADB_ADB_H
@@ -57,7 +57,6 @@ class LogFile;
 #include "adb_exceptionHolder.h"
 #include "adb_logfile.h"
 #include "adb_config.h"
-#include "adb_progress.h"
 #include "adb_instance.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -66,6 +65,7 @@ class LogFile;
 #include <list>
 #include <stdexcept>
 #include "adb_xmlCreator.h"
+#include "adb_condition.h"
 
 #ifdef __WIN__
 #include <process.h>
@@ -74,29 +74,8 @@ class LogFile;
 #define OS_PATH_SEP "/"
 #endif
 
-#ifdef __linux__
-#define LC_ALL_HINT " using `export LC_ALL=C`"
-#else
-#define LC_ALL_HINT ""
-#endif
-
-#define PROGRESS_NODE_CNT 100 // each 100 parsed node call progress callback
-
-#ifndef MIN
-#define MIN(a, b) ((a) < (b) ? (a) : (b))
-#endif
-#ifndef MAX
-#define MAX(a, b) ((a) > (b) ? (a) : (b))
-#endif
-
-#define CHECK_RUNTIME_ERROR(e)                                                         \
-    ((strstr(e.what(), "locale::facet::_S_create_c_locale") != NULL) ?                 \
-       string("Encoding error, please set locale encoding to C") + LC_ALL_HINT + "." : \
-       string("runtime_error: ") + e.what())
-
 using namespace std;
 
-//#define printf win32_printf
 #if defined(__MINGW32__) || defined(__MINGW64__)
 #define PRINTF_FORMAT __MINGW_PRINTF_FORMAT
 #else
@@ -109,19 +88,21 @@ class AdbField;
 using namespace xmlCreator;
 using namespace std;
 
+struct IncludeFileInfo;
+typedef map<string, IncludeFileInfo> IncludeFileMap;
 typedef map<string, string> AttrsMap;
-typedef vector<string> StringVector;
-typedef struct
+typedef map<string, AdbNode*> NodesMap;
+typedef vector<AdbConfig*> ConfigList;
+typedef map<string, AttrsMap> InstanceAttrs;
+typedef map<string, vector<string> > ExceptionsMap;
+
+struct IncludeFileInfo
 {
     string fullPath;
     string includedFromFile;
     int includedFromLine;
-} IncludeFileInfo;
-typedef map<string, IncludeFileInfo> IncludeFileMap;
-typedef map<string, AdbNode*> NodesMap;
-typedef vector<AdbConfig*> ConfigList;
-typedef map<string, AttrsMap> InstanceAttrs;
-typedef map<string, StringVector> ExceptionsMap;
+};
+
 class Adb
 {
 public:
@@ -135,12 +116,12 @@ public:
     //   3- check node size vs instance size
     bool loadFromString(const char* adbContents,
                         bool addReserved = false,
-                        AdbProgress* progressObj = NULL,
+                        bool evalExpr = false,
                         bool strict = true,
                         bool enforceExtraChecks = false);
     bool load(string fname,
               bool addReserved = false,
-              AdbProgress* progressObj = NULL,
+              bool evalExpr = false,
               bool strict = true,
               string includePath = "",
               string includeDir = "",
@@ -148,7 +129,8 @@ public:
               bool getAllExceptions = false,
               string logFile = "",
               bool checkDsAlign = false,
-              bool enforceGuiChecks = false);
+              bool enforceGuiChecks = false,
+              bool force_pad_32 = false);
     string toXml(vector<string> nodeNames = vector<string>(),
                  bool addRootNode = false,
                  string rootName = "MainNode",
@@ -157,11 +139,11 @@ public:
     AdbInstance* addMissingNodes(int depth, bool allowMultipleExceptions);
     AdbInstance* createLayout(string rootNodeName,
                               bool isExprEval = false,
-                              AdbProgress* progressObj = NULL,
                               int depth = -1, /* -1 means instantiate full tree */
                               bool ignoreMissingNodes = false,
                               bool getAllExceptions = false);
     vector<string> getNodeDeps(string nodeName);
+    void add_include(string fileName, string filePath, string included_from, int lineNumber);
     string getLastError();
 
     void fetchAdbExceptionsMap(ExceptionsMap otherMap);
@@ -187,32 +169,31 @@ public:
 
     /* For internal use */
 public:
-    StringVector includePaths;
+    vector<string> includePaths;
+    std::map<string, string> defines_map;
     string mainFileName;
     IncludeFileMap includedFiles;
-    StringVector warnings;
+    vector<string> warnings;
     ExceptionsMap adbExceptionMap;
 
 private:
-    vector<AdbInstance*> createInstance(AdbField* fieldDesc,
-                                        AdbInstance* parent,
-                                        map<string, string> vars,
-                                        bool isExprEval,
-                                        AdbProgress* progressObj,
-                                        int depth,
-                                        bool ignoreMissingNodes = false,
-                                        bool getAllExceptions = false);
-    u_int32_t calcArrOffset(AdbField* fieldDesc, AdbInstance* parent, u_int32_t arrIdx);
+    bool createInstance(AdbField* fieldDesc,
+                        AdbInstance* parent,
+                        map<string, string> vars,
+                        bool isExprEval,
+                        int depth,
+                        bool ignoreMissingNodes = false,
+                        bool getAllExceptions = false);
     string evalExpr(string expr, AttrsMap* vars);
     bool checkInstSizeConsistency(bool getAllExceptions = false);
-    void cleanInstAttrs();
 
 private:
     string _lastError;
-    AdbExpr _adbExpr;
     bool _checkDsAlign;
     bool _enforceGuiChecks;
     list<AdbInstance*> _unionSelectorEvalDeffered;
+    list<AdbInstance*> _conditionInstances;
+    list<AdbInstance*> _conditionalArrays;
     void checkInstanceOffsetValidity(AdbInstance* inst, AdbInstance* parent, bool allowMultipleExceptions);
     void throwExeption(bool allowMultipleExceptions, string exceptionTxt, string addedMsgMultiExp);
 };
