@@ -40,6 +40,7 @@
  */
 
 #include "mflash_dev_capability.h"
+#include <stdlib.h>
 
 // When (*status != MFE_OK) return value is undefined
 int is_four_byte_address_needed(mflash* mfl, MfError* status)
@@ -70,6 +71,7 @@ int is_four_byte_address_needed(mflash* mfl, MfError* status)
         case DeviceSpectrum3:
         case DeviceQuantum2:
         case DeviceQuantum3:
+        case DeviceArcusE:
         case DeviceSpectrum4:
         case DeviceBlueField2:
         case DeviceBlueField3:
@@ -95,7 +97,8 @@ int is_flash_enable_needed(mflash* mfl, MfError* status)
         return 1;
     }
     else if ((mfl->dm_dev_id == DeviceSecureHost) || (dm_is_5th_gen_hca(mfl->dm_dev_id)) ||
-             (dm_dev_is_gearbox(mfl->dm_dev_id)) || (dm_is_new_gen_switch(mfl->dm_dev_id)))
+             (dm_dev_is_gearbox(mfl->dm_dev_id)) || (dm_is_new_gen_switch(mfl->dm_dev_id)) ||
+             (dm_dev_is_retimer_arcuse(mfl->dm_dev_id)))
     {
         return 0;
     }
@@ -108,7 +111,7 @@ int is_flash_enable_needed(mflash* mfl, MfError* status)
 }
 
 // When (*status != MFE_OK) return value is undefined
-int is_icmdif_supported(mflash* mfl, MfError* status, int* is7NmSuppported)
+int is_icmdif_supported(mflash* mfl, MfError* status)
 {
     *status = MFE_OK;
 
@@ -135,17 +138,16 @@ int is_icmdif_supported(mflash* mfl, MfError* status, int* is7NmSuppported)
         case DeviceConnectX6LX:
         case DeviceGearBox:
         case DeviceGearBoxManager:
-            *is7NmSuppported = 0;
             return 1;
         case DeviceQuantum2:
         case DeviceQuantum3:
+        case DeviceArcusE:
         case DeviceSpectrum4:
         case DeviceConnectX7:
         case DeviceConnectX8:
         case DeviceBlueField3:
         case DeviceBlueField4:
         case DeviceAbirGearBox:
-            *is7NmSuppported = 1;
             return 1;
         default:
             *status = MFE_UNSUPPORTED_DEVICE;
@@ -153,3 +155,35 @@ int is_icmdif_supported(mflash* mfl, MfError* status, int* is7NmSuppported)
             return 1;
     }
 }
+
+FlashGen get_flash_gen(mflash* mfl)
+{
+    FlashGen gen;
+    switch (mfl->dm_dev_id)
+    {
+        case DeviceQuantum2:
+        case DeviceSpectrum4:
+        case DeviceConnectX7:
+        case DeviceBlueField3:
+        case DeviceAbirGearBox:
+        {
+            gen = SIX_GEN_FLASH;
+            break;
+        }
+        case DeviceQuantum3:
+        case DeviceArcusE:
+        case DeviceConnectX8:
+        case DeviceBlueField4:
+        {
+            gen = SEVEN_GEN_FLASH;
+            break;
+        }
+        default:
+        {
+            gen = LEGACY_FLASH;
+            break;
+        }
+    }
+    DPRINTF(("get_flash_gen: flash_gen = %d\n", gen));
+    return gen;
+}
