@@ -47,6 +47,7 @@
 
 #if !defined(NO_OPEN_SSL)
 #include <mlxsign_lib/mlxsign_lib.h>
+#include <mlxsign_lib/mlxsign_signer_interface.h>
 #if !defined(NO_DYNAMIC_ENGINE)
 #include <mlxsign_lib/mlxsign_openssl_engine.h>
 #endif
@@ -67,8 +68,6 @@ using namespace mlxcfg;
 
 #define TLVCLASS_OFFSET 24
 #define TLVCLASS_SIZE 8
-#define BIN_FILE_FINGERPRINT "MLNX.CONFIG.BIN!"
-#define BIN_FILE_FINGERPRINT_SIZE 16 // bytes
 #define RAW_FILE_FINGERPRINT "MLNX_RAW_TLV_FILE"
 #define XMLNS "http://www.mellanox.com/config"
 #define XML_ROOT "config"
@@ -133,15 +132,16 @@ const u_int8_t btcTokenId = 0x8;
 const u_int8_t rmcsTokenId = 0x10;
 const u_int8_t rmdtTokenId = 0x11;
 const u_int32_t idMlnxId = 0x10e;
+const u_int32_t idVendorId = 0x10f;
 
 void GenericCommander::supportsNVData()
 {
-    struct tools_open_nvqc nvqcTlv;
-    memset(&nvqcTlv, 0, sizeof(struct tools_open_nvqc));
+    struct reg_access_hca_mnvqc_reg_ext nvqcTlv;
+    memset(&nvqcTlv, 0, sizeof(struct reg_access_hca_mnvqc_reg_ext));
     MError rc;
     // "suspend" signals as we are going to take semaphores
     mft_signal_set_handling(1);
-    rc = reg_access_nvqc(_mf, REG_ACCESS_METHOD_GET, &nvqcTlv);
+    rc = reg_access_mnvqc(_mf, REG_ACCESS_METHOD_GET, &nvqcTlv);
     dealWithSignal();
     if (rc == ME_REG_ACCESS_BAD_PARAM || rc == ME_REG_ACCESS_INTERNAL_ERROR)
     {
@@ -195,7 +195,10 @@ void GenericCommander::excludeDuplicatedTLVs(vector<TLVConfView>& s, vector<TLVC
         {
             if ((*it).name == (*rIt).name)
             {
-                VECTOR_ITERATOR(ParamView, (*it).params, p) { (*rIt).params.push_back(*p); }
+                VECTOR_ITERATOR(ParamView, (*it).params, p)
+                {
+                    (*rIt).params.push_back(*p);
+                }
                 found = true;
                 break;
             }
@@ -253,7 +256,7 @@ void GenericCommander::queryConfigViews(std::vector<TLVConfView>& confs, const s
             {
                 (*it)->_port = i;
                 (*it)->_module = -1;
-                queryTLV((*it), result, qt);
+                queryTLV((*it), result, false, qt);
             }
         }
         else if (tlv->isModuleTargetClass())
@@ -262,20 +265,23 @@ void GenericCommander::queryConfigViews(std::vector<TLVConfView>& confs, const s
             {
                 (*it)->_port = 0;
                 (*it)->_module = i;
-                queryTLV((*it), result, qt);
+                queryTLV((*it), result, false, qt);
             }
         }
         else
         {
             (*it)->_port = 0;
             (*it)->_module = -1;
-            queryTLV((*it), result, qt);
+            queryTLV((*it), result, false, qt);
         }
         std::map<std::string, size_t>::iterator map_it = tlvViewMap.find(tlv->_mlxconfigName);
         if (map_it != tlvViewMap.end())
         {
             size_t index = (*map_it).second;
-            VECTOR_ITERATOR(ParamView, result, p) { confs[index].params.push_back(*p); }
+            VECTOR_ITERATOR(ParamView, result, p)
+            {
+                confs[index].params.push_back(*p);
+            }
         }
         else
         {
@@ -283,7 +289,10 @@ void GenericCommander::queryConfigViews(std::vector<TLVConfView>& confs, const s
             TLVConfView tlvConfView;
             tlv->getView(tlvConfView, _mf);
             tlvConfView.params.clear();
-            VECTOR_ITERATOR(ParamView, result, p) { tlvConfView.params.push_back(*p); }
+            VECTOR_ITERATOR(ParamView, result, p)
+            {
+                tlvConfView.params.push_back(*p);
+            }
             if (tlvConfView.params.size() > 0)
             {
                 confs.push_back(tlvConfView);
@@ -336,7 +345,10 @@ void GenericCommander::getConfigViews(std::vector<TLVConfView>& confs, const std
             TLVConfView tlvConfView;
             tlv->getView(tlvConfView, _mf);
 
-            VECTOR_ITERATOR(ParamView, tlvConfView.params, p) { confs[index].params.push_back(*p); }
+            VECTOR_ITERATOR(ParamView, tlvConfView.params, p)
+            {
+                confs[index].params.push_back(*p);
+            }
         }
         else
         {
@@ -536,32 +548,7 @@ bool GenericCommander::checkDependency(TLVConf* cTLV, string dStr)
         {
             string dTLVName = (*it).substr(0, dotPos).replace(0, 1, "");
             string dParamName = (*it).substr(dotPos + 1);
-            // to allow cross class/port dependency we need to check dependency for
-            // port 0 and for port 1 (higher port numbers will act the same)
-            int lookForPorts[] = {int(cTLV->_port), (int(cTLV->_port) == 0) ? 1 : 0};
-            TLVConf* dTLV = NULL;
-            for (int ports = 0; ports < 2; ports++)
-            {
-                try
-                {
-                    if (lookForPorts[ports] == 0)
-                    {
-                        dTLV = _dbManager->getTLVByName(dTLVName, lookForPorts[ports], cTLV->_module);
-                    }
-                    else
-                    {
-                        dTLV = _dbManager->getTLVByName(dTLVName, lookForPorts[ports], -1);
-                    }
-                    if (dTLV != NULL)
-                    {
-                        break;
-                    }
-                }
-                catch (MlxcfgTLVNotFoundException e)
-                { // if TLV not found exception continue to search
-                    continue;
-                }
-            }
+            TLVConf* dTLV = _dbManager->getDependencyTLVByName(dTLVName, cTLV->_port, cTLV->_module);
             if (dTLV == NULL)
             {
                 throw MlxcfgTLVNotFoundException(dTLVName.c_str());
@@ -594,17 +581,21 @@ void GenericCommander::filterByDependency(TLVConf* cTLV,
     }
 }
 
-void GenericCommander::queryTLV(TLVConf* tlv, vector<ParamView>& paramsConf, QueryType qt)
+void GenericCommander::queryTLV(TLVConf* tlv, vector<ParamView>& paramsConf, bool isWriteOperation, QueryType qt)
 {
-    if (!tlv->_cap && tlv->isMlxconfigSupported() && tlv->isFWSupported(_mf, true))
+    if (!tlv->_cap && tlv->isMlxconfigSupported() && tlv->isFWSupported(_mf, isWriteOperation))
     {
         vector<pair<ParamView, string>> dependencyTable = tlv->query(_mf, qt);
         filterByDependency(tlv, dependencyTable, paramsConf);
+        for (auto& p : paramsConf)
+        {
+            p.isReadOnlyParam = tlv->_isReadOnly;
+        }
     }
     return;
 }
 
-void GenericCommander::queryParamViews(vector<ParamView>& params, QueryType qt)
+void GenericCommander::queryParamViews(vector<ParamView>& params, bool isWriteOperation, QueryType qt)
 {
     vector<ParamView> pc;
     std::set<TLVConf*> uniqueTLVs;
@@ -644,7 +635,10 @@ void GenericCommander::queryParamViews(vector<ParamView>& params, QueryType qt)
         }
     }
 
-    SET_ITERATOR(TLVConf*, uniqueTLVs, it) { queryTLV(*it, pc, qt); }
+    SET_ITERATOR(TLVConf*, uniqueTLVs, it)
+    {
+        queryTLV(*it, pc, isWriteOperation, qt);
+    }
 
     VECTOR_ITERATOR(ParamView, params, i)
     {
@@ -664,6 +658,7 @@ void GenericCommander::queryParamViews(vector<ParamView>& params, QueryType qt)
             if (mlxconfigNameI == mlxconfigNameJ ||
                 (mlxconfigNameI + getArraySuffixByInterval(iIndex)) == mlxconfigNameJ)
             {
+                i->isReadOnlyParam = j->isReadOnlyParam;
                 if (isIIndexed)
                 {
                     if (iIndex >= j->arrayVal.size() &&
@@ -710,7 +705,7 @@ void GenericCommander::queryAll(vector<ParamView>& params, vector<string>& faile
                 {
                     (*it)->_port = i;
                     (*it)->_module = -1;
-                    queryTLV((*it), result, qt);
+                    queryTLV((*it), result, false, qt);
                 }
             }
             else if ((*it)->isModuleTargetClass())
@@ -719,14 +714,14 @@ void GenericCommander::queryAll(vector<ParamView>& params, vector<string>& faile
                 {
                     (*it)->_port = 0;
                     (*it)->_module = i;
-                    queryTLV((*it), result, qt);
+                    queryTLV((*it), result, false, qt);
                 }
             }
             else
             {
                 (*it)->_port = 0;
                 (*it)->_module = -1;
-                queryTLV((*it), result, qt);
+                queryTLV((*it), result, false, qt);
             }
             params.insert(params.end(), result.begin(), result.end());
         }
@@ -742,7 +737,7 @@ void GenericCommander::getCfg(ParamView& pv, QueryType qt)
     vector<ParamView> pc;
 
     TLVConf* tlv = _dbManager->getTLVByParamMlxconfigName(pv.mlxconfigName, 0, _mf);
-    queryTLV(tlv, pc, qt);
+    queryTLV(tlv, pc, false, qt);
 
     VECTOR_ITERATOR(ParamView, pc, j)
     {
@@ -781,7 +776,7 @@ void GenericCommander::setCfg(vector<ParamView>& params, bool force)
         }
         else
         {
-            tlvMap[(*p).mlxconfigName]->updateParamByMlxconfigName(mlxconfigName, (*p).strVal);
+            tlvMap[(*p).mlxconfigName]->updateParamByMlxconfigName(mlxconfigName, (*p).strVal, _mf);
         }
     }
 
@@ -823,13 +818,13 @@ void GenericCommander::setCfg(vector<ParamView>& params, bool force)
 
 bool GenericCommander::isDefaultSupported()
 {
-    struct tools_open_nvqgc nvqgcTlv;
+    struct reg_access_hca_mnvgc_reg_ext mnvgc_reg;
 
-    memset(&nvqgcTlv, 0, sizeof(struct tools_open_nvqgc));
+    memset(&mnvgc_reg, 0, sizeof(struct reg_access_hca_mnvgc_reg_ext));
     MError rc;
 
     mft_signal_set_handling(1);
-    rc = reg_access_nvqgc(_mf, REG_ACCESS_METHOD_GET, &nvqgcTlv);
+    rc = reg_access_mnvgc(_mf, REG_ACCESS_METHOD_GET, &mnvgc_reg);
     dealWithSignal();
     if (rc == ME_REG_ACCESS_BAD_PARAM || rc == ME_REG_ACCESS_INTERNAL_ERROR)
     {
@@ -837,7 +832,7 @@ bool GenericCommander::isDefaultSupported()
     }
     else if (rc == ME_OK)
     {
-        return nvqgcTlv.read_factory_settings_support;
+        return mnvgc_reg.nvda_read_factory_settings;
     }
     throw MlxcfgException("Error when checked if Firmware supports querying "
                           "default configurations or not: %s.",
@@ -846,13 +841,13 @@ bool GenericCommander::isDefaultSupported()
 
 bool GenericCommander::isCurrentSupported()
 {
-    struct tools_open_nvqgc nvqgcTlv;
+    struct reg_access_hca_mnvgc_reg_ext mnvgc_reg;
 
-    memset(&nvqgcTlv, 0, sizeof(struct tools_open_nvqgc));
+    memset(&mnvgc_reg, 0, sizeof(struct reg_access_hca_mnvgc_reg_ext));
     MError rc;
 
     mft_signal_set_handling(1);
-    rc = reg_access_nvqgc(_mf, REG_ACCESS_METHOD_GET, &nvqgcTlv);
+    rc = reg_access_mnvgc(_mf, REG_ACCESS_METHOD_GET, &mnvgc_reg);
     dealWithSignal();
     if (rc == ME_REG_ACCESS_BAD_PARAM || rc == ME_REG_ACCESS_INTERNAL_ERROR)
     {
@@ -860,7 +855,7 @@ bool GenericCommander::isCurrentSupported()
     }
     else if (rc == ME_OK)
     {
-        return nvqgcTlv.nvda_read_current_settings;
+        return mnvgc_reg.nvda_read_current_settings;
     }
     throw MlxcfgException("Error when checked if Firmware supports "
                           "querying current configurations or not: %s.",
@@ -879,12 +874,12 @@ void GenericCommander::clearSemaphore()
 void GenericCommander::invalidateCfgs()
 {
     int rc;
-    struct tools_open_nvia nviaTlv;
-    u_int8_t buffer[TOOLS_OPEN_NVIA_SIZE] = {0};
-    memset(&nviaTlv, 0, sizeof(struct tools_open_nvia));
-    tools_open_nvia_pack(&nviaTlv, buffer);
+    struct reg_access_hca_mnvia_reg_ext nviaTlv;
+    u_int8_t buffer[REG_ACCESS_HCA_MNVIA_REG_EXT_SIZE] = {0};
+    memset(&nviaTlv, 0, sizeof(struct reg_access_hca_mnvia_reg_ext));
+    reg_access_hca_mnvia_reg_ext_pack(&nviaTlv, buffer);
     mft_signal_set_handling(1);
-    rc = reg_access_nvia(_mf, REG_ACCESS_METHOD_SET, &nviaTlv);
+    rc = reg_access_mnvia(_mf, REG_ACCESS_METHOD_SET, &nviaTlv);
     dealWithSignal();
 
     if (rc)
@@ -909,7 +904,10 @@ void GenericCommander::invalidateCfg(const std::string& configName)
         throw MlxcfgException("The configuration %s was not found", configName.c_str());
     }
 
-    VECTOR_ITERATOR(TLVConf*, tlvArr, it) { (*it)->invalidate(_mf); }
+    VECTOR_ITERATOR(TLVConf*, tlvArr, it)
+    {
+        (*it)->invalidate(_mf);
+    }
 }
 
 const char* GenericCommander::loadConfigurationGetStr()
@@ -1145,6 +1143,7 @@ void GenericCommander::binTLV2TLVConf(const vector<u_int32_t>& binTLV, TLVConf*&
     tlv->_attrs[WRITER_ID_ATTR] = numToStr(hdr.writer_id);
     tlv->_attrs[RD_EN_ATTR] = numToStr(hdr.rd_en);
     tlv->_attrs[OVR_EN_ATTR] = numToStr(hdr.over_en);
+    tlv->_attrs[PRIORITY_ATTR] = PriorityNumToStr(hdr.priority);
     if (tlvClass == Physical_Port)
     {
         tlv->_attrs[PORT_ATTR] = numToStr(type.per_port.port);
@@ -1218,7 +1217,7 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
     xmlDocPtr doc;
     xmlNodePtr root, currTlv, currParam;
     xmlChar *portAttr = NULL, *moduleAttr = NULL, *hostAttr = NULL, *funcAttr = NULL, *rdEnAttr = NULL,
-            *ovrEnAttr = NULL, *xmlVal = NULL, *indexAttr = NULL, *writerIdAttr = NULL;
+            *priorityAttr = NULL, *ovrEnAttr = NULL, *xmlVal = NULL, *indexAttr = NULL, *writerIdAttr = NULL;
 
     doc = xmlReadMemory(xmlContent.c_str(), xmlContent.size(), "noname.xml", NULL, 0);
     if (!doc)
@@ -1264,7 +1263,8 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
                 isAllPorts = true;
                 port = 1;
             }
-            else if (!strToNum((const char*)portAttr, port) || (1 <= port && (int32_t)port <= tlvConf->getMaxPort(_mf)))
+            else if (!strToNum((const char*)portAttr, port) ||
+                     !(1 <= port && (int32_t)port <= tlvConf->getMaxPort(_mf)))
             {
                 throw MlxcfgException("Illegal value of port attribute %s", (const char*)portAttr);
             }
@@ -1278,7 +1278,7 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
                 isAllModules = true;
                 module = 0;
             }
-            else if (!strToNum((const char*)moduleAttr, u_module) || ((int32_t)u_module <= tlvConf->getMaxModule()))
+            else if (!strToNum((const char*)moduleAttr, u_module) || !(u_module <= (u_int32_t)tlvConf->getMaxModule()))
             {
                 throw MlxcfgException("Illegal value of module attribute %s", (const char*)portAttr);
             }
@@ -1301,6 +1301,7 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
                 GET_AND_SET_ATTR(writerIdAttr, currTlv, WRITER_ID_ATTR)
                 GET_AND_SET_ATTR(ovrEnAttr, currTlv, OVR_EN_ATTR)
                 GET_AND_SET_ATTR(rdEnAttr, currTlv, RD_EN_ATTR)
+                GET_AND_SET_ATTR(priorityAttr, currTlv, PRIORITY_ATTR)
                 GET_AND_SET_ATTR(hostAttr, currTlv, HOST_ATTR)
                 GET_AND_SET_ATTR(funcAttr, currTlv, FUNC_ATTR)
 
@@ -1374,6 +1375,8 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
             }
             tlvs.push_back(tlvConf);
             currTlv = currTlv->next;
+            XMLFREE_AND_SET_NULL(portAttr)
+            XMLFREE_AND_SET_NULL(moduleAttr)
         }
         if (tlvs.size() == 0)
         {
@@ -1387,12 +1390,16 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
         XMLFREE_AND_SET_NULL(moduleAttr)
         XMLFREE_AND_SET_NULL(ovrEnAttr)
         XMLFREE_AND_SET_NULL(rdEnAttr)
+        XMLFREE_AND_SET_NULL(priorityAttr)
         XMLFREE_AND_SET_NULL(hostAttr)
         XMLFREE_AND_SET_NULL(funcAttr)
         XMLFREE_AND_SET_NULL(xmlVal)
         xmlFreeDoc(doc);
         doc = NULL;
-        VECTOR_ITERATOR(TLVConf*, tlvs, itTlvConf) { delete *itTlvConf; }
+        VECTOR_ITERATOR(TLVConf*, tlvs, itTlvConf)
+        {
+            delete *itTlvConf;
+        }
         throw e;
     }
     XMLFREE_AND_SET_NULL(writerIdAttr)
@@ -1400,6 +1407,7 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
     XMLFREE_AND_SET_NULL(moduleAttr)
     XMLFREE_AND_SET_NULL(ovrEnAttr)
     XMLFREE_AND_SET_NULL(rdEnAttr)
+    XMLFREE_AND_SET_NULL(priorityAttr)
     XMLFREE_AND_SET_NULL(hostAttr)
     XMLFREE_AND_SET_NULL(funcAttr)
     XMLFREE_AND_SET_NULL(xmlVal)
@@ -1452,19 +1460,51 @@ void GenericCommander::XML2Raw(const string& xmlContent, string& raw)
         }
     }
 
-    VECTOR_ITERATOR(TLVConf*, tlvs, tlvConf) { delete *tlvConf; }
+    VECTOR_ITERATOR(TLVConf*, tlvs, tlvConf)
+    {
+        delete *tlvConf;
+    }
 }
 
 void GenericCommander::TLVConf2Bin(const vector<TLVConf*>& tlvs, vector<u_int32_t>& buff, bool withHeader)
 {
+    int i = 0;
     CONST_VECTOR_ITERATOR(TLVConf*, tlvs, tlvConf)
     {
-        vector<u_int32_t> tmpBuff;
-        (*tlvConf)->genBin(tmpBuff, withHeader);
-        buff.insert(buff.end(), tmpBuff.begin(), tmpBuff.end());
+        if ((*tlvConf)->_attrs[PORT_ATTR] == ALL_ATTR_VAL)
+        {
+            for (i = 1; i <= (*tlvConf)->getMaxPort(_mf); i++)
+            {
+                (*tlvConf)->_attrs[PORT_ATTR] = i;
+                (*tlvConf)->_port = i;
+                vector<u_int32_t> tmpBuff;
+                (*tlvConf)->genBin(tmpBuff, withHeader);
+                buff.insert(buff.end(), tmpBuff.begin(), tmpBuff.end());
+            }
+        }
+        else if ((*tlvConf)->_attrs[MODULE_ATTR] == ALL_ATTR_VAL)
+        {
+            for (i = 0; i <= (*tlvConf)->getMaxModule(); i++)
+            {
+                (*tlvConf)->_attrs[MODULE_ATTR] = i;
+                (*tlvConf)->_module = i;
+                vector<u_int32_t> tmpBuff;
+                (*tlvConf)->genBin(tmpBuff, withHeader);
+                buff.insert(buff.end(), tmpBuff.begin(), tmpBuff.end());
+            }
+        }
+        else
+        {
+            vector<u_int32_t> tmpBuff;
+            (*tlvConf)->genBin(tmpBuff, withHeader);
+            buff.insert(buff.end(), tmpBuff.begin(), tmpBuff.end());
+        }
     }
 
-    CONST_VECTOR_ITERATOR(TLVConf*, tlvs, tlvConf) { delete *tlvConf; }
+    CONST_VECTOR_ITERATOR(TLVConf*, tlvs, tlvConf)
+    {
+        delete *tlvConf;
+    }
 }
 
 void GenericCommander::XML2Bin(const string& xml, vector<u_int32_t>& buff, bool withHeader)
@@ -1484,86 +1524,45 @@ void GenericCommander::sign(vector<u_int32_t>& buff,
 {
     (void)keyPairUUid;
 #if !defined(UEFI_BUILD) && !defined(NO_OPEN_SSL) && !defined(NO_DYNAMIC_ENGINE)
-    MlxSignSHA* mlxSignSHA = NULL;
     vector<u_int32_t> encDigestDW;
     vector<u_int8_t> digest, encDigest, bytesBuff;
     MlxSign::SHAType shaType;
+    unique_ptr<MlxSign::Signer> signer = nullptr;
 
     copyDwVectorToBytesVector(buff, bytesBuff);
 
-    if (!openssl_key_identifier.empty())
+    if (openssl_key_identifier.empty() && privateKeyFile.empty())
     {
-        // Sign with HSM engine
-        shaType = MlxSign::SHA512;
-        MlxSign::OpensslEngineSigner engineSigner(openssl_engine, openssl_key_identifier);
-        int rc = engineSigner.init();
-        if (!rc)
-        {
-            int keySize = engineSigner.getPrivateKeySize();
-            if ((keySize != KEY_SIZE_256) && (keySize != KEY_SIZE_512))
-            {
-                throw MlxcfgException("Invalid length of private key(%d bytes). It is "
-                                      "recommanded to use 4096 bit key.\n",
-                                      keySize);
-            }
-            // Init successfuly with valid key -> can continue to sign the massage
-            rc = engineSigner.sign(bytesBuff, encDigest);
-        }
-        if (rc)
-        {
-            throw MlxcfgException("Failed to set private key and sign with %s "
-                                  "OpenSSL engine (rc = 0x%x)\n",
-                                  openssl_engine.c_str(), rc);
-        }
+        shaType = MlxSign::SHA256;
+        MlxSignSHA256 mlxSignSHA;
+        mlxSignSHA << bytesBuff;
+        mlxSignSHA.getDigest(digest);
+        encDigest.insert(encDigest.begin(), digest.begin(), digest.end());
     }
     else
     {
-        MlxSignRSA rsa;
-        if (privateKeyFile.empty())
+        if (!openssl_key_identifier.empty())
         {
-            shaType = MlxSign::SHA256;
-            mlxSignSHA = new MlxSignSHA256();
+            // Sign with local HSM engine
+            shaType = MlxSign::SHA512;
+#if !defined(NO_DYNAMIC_ENGINE)
+            signer = unique_ptr<MlxSign::Signer>(new MlxSign::MlxSignRSAViaHSM(openssl_engine, openssl_key_identifier));
+#else
+            reportErr(true, "Open SSL functionality is not supported.\n");
+#endif
         }
         else
         {
-            int rc = rsa.setPrivKeyFromFile(privateKeyFile);
-            if (rc)
-            {
-                throw MlxcfgException("Failed to set private key (rc = 0x%x)\n", rc);
-            }
-            int privKeyLength = rsa.getPrivKeyLength();
-            if (privKeyLength == 0x100)
-            {
-                shaType = MlxSign::SHA256;
-                mlxSignSHA = new MlxSignSHA256();
-            }
-            else if (privKeyLength == 0x200)
-            {
-                shaType = MlxSign::SHA512;
-                mlxSignSHA = new MlxSignSHA512();
-            }
-            else
-            {
-                throw MlxcfgException("Invalid length of private key(%d bytes)", privKeyLength);
-            }
+            signer = unique_ptr<MlxSign::Signer>(new MlxSign::MlxSignRSAViaOpenssl(privateKeyFile));
         }
 
-        (*mlxSignSHA) << bytesBuff;
-        mlxSignSHA->getDigest(digest);
-        delete mlxSignSHA;
+        if (signer != nullptr && signer->Init() != MlxSign::MLX_SIGN_SUCCESS)
+        {
+            signer.reset();
+            throw MlxcfgException("Failed to initialize signer.\n");
+        }
 
-        if (privateKeyFile.empty())
-        {
-            encDigest.insert(encDigest.begin(), digest.begin(), digest.end());
-        }
-        else
-        {
-            int rc = rsa.sign(shaType, digest, encDigest);
-            if (rc)
-            {
-                throw MlxcfgException("Failed to encrypt the digest (rc = 0x%x)\n", rc);
-            }
-        }
+        signer->Sign(bytesBuff, encDigest);
     }
 
     // fetch the signature tlv from the database and fill in the data
@@ -1652,8 +1651,12 @@ void GenericCommander::checkConfTlvs(const vector<TLVConf*>& tlvs, FwComponent::
 {
     bool dbgCompFound = false;
     bool csCompFound = false;
+    bool rmdtCompFound = false;
+    bool rmcsCompFound = false;
     bool foundApplicableTLV = false;
     bool idMlnxCompFound = false;
+    bool idVendorCompFound = false;
+    bool deviceUniqueFound = false;
     compsId = FwComponent::COMPID_UNKNOWN;
     u_int32_t type = 0;
     mget_mdevs_type(_mf, &type);
@@ -1678,12 +1681,12 @@ void GenericCommander::checkConfTlvs(const vector<TLVConf*>& tlvs, FwComponent::
         }
         else if (tlv->_tlvClass == NVFile && tlv->_id == rmcsTokenId)
         {
-            csCompFound = true;
+            rmcsCompFound = true;
             compsId = FwComponent::COMPID_RMCS_TOKEN;
         }
         else if (tlv->_tlvClass == NVFile && tlv->_id == rmdtTokenId)
         {
-            csCompFound = true;
+            rmdtCompFound = true;
             compsId = FwComponent::COMPID_RMDT_TOKEN;
         }
         else if (tlv->_tlvClass == 0x0 && tlv->_id == idMlnxId)
@@ -1691,25 +1694,48 @@ void GenericCommander::checkConfTlvs(const vector<TLVConf*>& tlvs, FwComponent::
             idMlnxCompFound = true;
             compsId = FwComponent::COMPID_MLNX_NVCONFIG;
         }
+        else if (tlv->_tlvClass == 0x0 && tlv->_id == idVendorId)
+        {
+            idVendorCompFound = true;
+            compsId = FwComponent::COMPID_OEM_NVCONFIG;
+        }
         else if (tlv->_name == "file_applicable_to")
         {
             foundApplicableTLV = true;
         }
+        else if (tlv->_name == "file_device_unique")
+        {
+            deviceUniqueFound = true;
+        }
 
-        if ((type & (MST_USB | MST_USB_DIMAX)) && (compsId == FwComponent::COMPID_UNKNOWN))
+        if ((type & (MST_USB_DIMAX)) && (compsId == FwComponent::COMPID_UNKNOWN))
         { // MST_USB tlv's must have component
             throw MlxcfgException("MTUSB device is not supported.");
         }
     }
 
-    if (!dbgCompFound && !csCompFound && !idMlnxCompFound)
+    if (deviceUniqueFound)
+    {
+        if (compsId == FwComponent::COMPID_CS_TOKEN)
+        {
+            compsId = FwComponent::COMPID_CRCS_TOKEN;
+        }
+        else if (compsId == FwComponent::COMPID_DBG_TOKEN)
+        {
+            compsId = FwComponent::COMPID_CRDT_TOKEN;
+        }
+    }
+
+    u_int32_t numOfCompsFound = (dbgCompFound ? 1 : 0) + (csCompFound ? 1 : 0) + (rmcsCompFound ? 1 : 0) +
+                                (rmdtCompFound ? 1 : 0) + (idMlnxCompFound ? 1 : 0) + (idVendorCompFound ? 1 : 0);
+    if (numOfCompsFound == 0)
     {
         throw MlxcfgException("Unsupported device: No debug tokens or CS tokens or "
-                              "MLNX ID Components were found for "
+                              "MLNX/Vendor ID Components were found for "
                               "this device");
     }
 
-    if ((dbgCompFound && csCompFound) || (dbgCompFound && idMlnxCompFound) || (csCompFound && idMlnxCompFound))
+    if (numOfCompsFound > 1)
     {
         throw MlxcfgException("Only one component is allowed");
     }
@@ -1729,7 +1755,7 @@ void GenericCommander::orderConfTlvs(vector<TLVConf*>& tlvs)
         TLVConf* tlv = *it;
         if (((tlv->_tlvClass == NVFile) &&
              (tlv->_id == debugTokenId || tlv->_id == csTokenId || tlv->_id == btcTokenId)) ||
-            (tlv->_tlvClass == Global && tlv->_id == idMlnxId))
+            ((tlv->_tlvClass == Global) && (tlv->_id == idMlnxId || tlv->_id == idVendorId)))
         {
             *it = tlvs.front();
             tlvs.front() = tlv;
@@ -1765,6 +1791,8 @@ void GenericCommander::createConf(const string& xml, vector<u_int32_t>& buff)
 
     XML2TLVConf(xml, tlvs);
 
+    removeSignatureTlvs(tlvs);
+
     checkConfTlvs(tlvs, compsId);
 
     orderConfTlvs(tlvs);
@@ -1873,34 +1901,50 @@ void GenericCommander::raw2XML(const vector<string>& lines, string& xmlTemplate)
     // printf("xmlTemplate=\n%s", xmlTemplate.c_str());
 }
 
+void GenericCommander::removeSignatureTlvs(vector<TLVConf*>& tlvs)
+{
+    auto tlv = tlvs.begin();
+    while (tlv != tlvs.end())
+    {
+        if ((*tlv)->_name == "file_signature")
+        {
+            tlv = tlvs.erase(tlv);
+        }
+        else
+        {
+            ++tlv;
+        }
+    }
+}
+
 /*
  * RawCfgParams5thGen Class implementation
  */
 RawCfgParams5thGen::RawCfgParams5thGen()
 {
-    memset(&_nvdaTlv, 0, sizeof(struct tools_open_nvda));
+    memset(&_nvdaTlv, 0, sizeof(tools_open_mnvda));
 }
 
 int RawCfgParams5thGen::setRawData(const std::vector<u_int32_t>& tlvBuff)
 {
-    if (tlvBuff.size() * 4 > TOOLS_OPEN_NVDA_SIZE)
+    if (tlvBuff.size() * 4 > TOOLS_OPEN_MNVDA_SIZE)
     {
         return errmsg(MCE_BAD_PARAM_VAL,
                       "TLV size exceeds maximal limit. Maximum size is 0x%x bytes, "
                       "actual length is 0x%x bytes",
-                      TOOLS_OPEN_NVDA_SIZE, (u_int32_t)(tlvBuff.size() * 4));
+                      TOOLS_OPEN_MNVDA_SIZE, (u_int32_t)(tlvBuff.size() * 4));
     }
     _tlvBuff = tlvBuff;
-    memset(&_nvdaTlv, 0, sizeof(struct tools_open_nvda));
+    memset(&_nvdaTlv, 0, sizeof(struct tools_open_mnvda));
     std::vector<u_int32_t> tlvBuffBe = _tlvBuff;
-    tlvBuffBe.resize(TOOLS_OPEN_NVDA_SIZE >> 2);
-    memset(&tlvBuffBe[0], 0, TOOLS_OPEN_NVDA_SIZE);
+    tlvBuffBe.resize(TOOLS_OPEN_MNVDA_SIZE >> 2);
+    memset(&tlvBuffBe[0], 0, TOOLS_OPEN_MNVDA_SIZE);
     tlvBuffBe.insert(tlvBuffBe.begin(), _tlvBuff.begin(), _tlvBuff.end());
     for (std::vector<u_int32_t>::iterator it = tlvBuffBe.begin(); it != tlvBuffBe.end(); it++)
     {
         *it = __cpu_to_be32(*it);
     }
-    tools_open_nvda_unpack(&_nvdaTlv, ((u_int8_t*)(&tlvBuffBe[0])));
+    tools_open_mnvda_unpack(&_nvdaTlv, ((u_int8_t*)(&tlvBuffBe[0])));
     _nvdaTlv.nv_hdr.writer_id = WRITER_ID_ICMD_MLXCONFIG_SET_RAW;
     return verifyTlv();
 }
@@ -1908,9 +1952,9 @@ int RawCfgParams5thGen::setRawData(const std::vector<u_int32_t>& tlvBuff)
 std::vector<u_int32_t> RawCfgParams5thGen::getRawData()
 {
     std::vector<u_int32_t> tlvBuff;
-    tlvBuff.resize(TOOLS_OPEN_NVDA_SIZE >> 2);
-    memset(&tlvBuff[0], 0, TOOLS_OPEN_NVDA_SIZE >> 2);
-    tools_open_nvda_pack(&_nvdaTlv, ((u_int8_t*)(&tlvBuff[0])));
+    tlvBuff.resize(TOOLS_OPEN_MNVDA_SIZE >> 2);
+    memset(&tlvBuff[0], 0, TOOLS_OPEN_MNVDA_SIZE >> 2);
+    tools_open_mnvda_pack(&_nvdaTlv, ((u_int8_t*)(&tlvBuff[0])));
     for (std::vector<u_int32_t>::iterator it = tlvBuff.begin(); it != tlvBuff.end(); it++)
     {
         *it = __be32_to_cpu(*it);
@@ -1925,7 +1969,7 @@ int RawCfgParams5thGen::setOnDev(mfile* mf, RawTlvMode mode)
     int rc;
     mft_signal_set_handling(1);
     DEBUG_PRINT_SEND(&_nvdaTlv, nvda);
-    rc = reg_access_nvda(mf, mode == SET_RAW ? REG_ACCESS_METHOD_SET : REG_ACCESS_METHOD_GET, &_nvdaTlv);
+    rc = reg_access_mnvda(mf, mode == SET_RAW ? REG_ACCESS_METHOD_SET : REG_ACCESS_METHOD_GET, &_nvdaTlv);
     DEBUG_PRINT_RECEIVE(&_nvdaTlv, nvda);
     dealWithSignal();
     if (rc)
