@@ -48,6 +48,7 @@
 #include "mlxcfg_view.h"
 #include "mlxcfg_utils.h"
 #include <mft_utils.h>
+#include <tools_layouts/reg_access_switch_layouts.h>
 
 using namespace std;
 
@@ -99,7 +100,7 @@ void MlxCfg::printHelp()
     printf("\n");
     printf(IDENT "COMMANDS SUMMARY\n");
     printf(IDENT2 "%-24s : %s\n", "clear_semaphore", "clear the tool semaphore.");
-    printf(IDENT2 "%-24s : %s\n", "i|show_confs", "display informations about all configurations.");
+    printf(IDENT2 "%-24s : %s\n", "i|show_confs", "display information about all configurations.");
     printf(IDENT2 "%-24s : %s\n", "q|query", "query supported configurations.");
     printf(IDENT2 "%-24s : %s\n", "r|reset", "reset all configurations to their default value.");
     printf(IDENT2 "%-24s : %s\n", "s|set", "set configurations to a specific device.");
@@ -141,15 +142,6 @@ void MlxCfg::printHelp()
            MLXCFG_NAME " -d " MST_DEV_EXAMPLE2 " -f conf_file set_raw");
     printf(IDENT2 "%-35s: %s\n", "To reset configuration", MLXCFG_NAME " -d " MST_DEV_EXAMPLE " reset");
     printf("\n");
-    printf(IDENT "Supported devices:\n");
-    printf(IDENT2 "4th Generation devices: ConnectX3, ConnectX3-Pro (FW 2.31.5000 and above).\n");
-    printf(IDENT2 "5th Generation devices: ConnectIB, ConnectX4, ConnectX4-LX, ConnectX5, connectX5-Ex.\n");
-    printf(IDENT2 "6th Generation devices: BlueField, BlueField2, ConnectX6, ConnectX6-DX, ConnectX6-LX\n");
-    printf(IDENT2 "Switches: Switch-IB, Switch-IB2,Spectrum, Spectrum2, Spectrum3, Quantum, Quantum2\n");
-
-    printf("\n");
-    printf(IDENT "Note: query device to view supported configurations by Firmware.\n");
-    printf("\n");
 }
 
 void MlxCfg::printVersion()
@@ -176,20 +168,21 @@ bool MlxCfg::tagExsists(string tag)
 
 inline const char* cmdNVInputFileTag(mlxCfgCmd cmd, const char* def)
 {
-    return (cmd == Mc_XML2Raw || cmd == Mc_XML2Bin || cmd == Mc_CreateConf) ?
-             "XML" :
-             (cmd == Mc_Raw2XML) ? "Raw" :
-                                   (cmd == Mc_GenXMLTemplate) ? "TLVs" : (cmd == Mc_Apply) ? "Configuration" : def;
+    return (cmd == Mc_XML2Raw || cmd == Mc_XML2Bin || cmd == Mc_CreateConf) ? "XML" :
+           (cmd == Mc_Raw2XML)                                              ? "Raw" :
+           (cmd == Mc_GenXMLTemplate)                                       ? "TLVs" :
+           (cmd == Mc_Apply)                                                ? "Configuration" :
+                                                                              def;
 }
 
 inline const char* cmdNVOutputFileTag(mlxCfgCmd cmd, const char* def)
 {
-    return (cmd == Mc_XML2Raw) ?
-             "Raw" :
-             (cmd == Mc_Raw2XML) ?
-             "XML" :
-             (cmd == Mc_GenXMLTemplate) ? "XML" :
-                                          (cmd == Mc_XML2Bin) ? "Bin" : (cmd == Mc_CreateConf) ? "Configuration" : def;
+    return (cmd == Mc_XML2Raw)        ? "Raw" :
+           (cmd == Mc_Raw2XML)        ? "XML" :
+           (cmd == Mc_GenXMLTemplate) ? "XML" :
+           (cmd == Mc_XML2Bin)        ? "Bin" :
+           (cmd == Mc_CreateConf)     ? "Configuration" :
+                                        def;
 }
 
 mlxCfgStatus MlxCfg::extractNVInputFile(int argc, char* argv[])
@@ -387,23 +380,6 @@ mlxCfgStatus MlxCfg::extractSetCfgArgs(int argc, char* argv[])
     return MLX_CFG_OK;
 }
 
-Device_Type MlxCfg::getDeviceTypeFromString(string inStr)
-{
-    mft_utils::to_lowercase(inStr);
-    if (inStr == "switch")
-    {
-        return Device_Type::Switch;
-    }
-    else if (inStr == "hca")
-    {
-        return Device_Type::HCA;
-    }
-    else
-    {
-        return Device_Type::UNSUPPORTED_DEVICE;
-    }
-}
-
 mlxCfgStatus MlxCfg::getNumberFromString(const char* str, u_int32_t& num)
 {
     char* end = NULL;
@@ -417,6 +393,7 @@ mlxCfgStatus MlxCfg::getNumberFromString(const char* str, u_int32_t& num)
 
 mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
 {
+    mlxCfgStatus status = MLX_CFG_OK;
     int i = 1;
     for (; i < argc; i++)
     {
@@ -562,7 +539,7 @@ mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
             _mlxParams.cmd = Mc_GenXMLTemplate;
             break;
         }
-        else if (arg == "raw2xml" || arg == "r")
+        else if (arg == "raw2xml")
         {
             _mlxParams.cmd = Mc_Raw2XML;
             break;
@@ -613,7 +590,8 @@ mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
     }
 
     if ((_mlxParams.cmd == Mc_Set || _mlxParams.cmd == Mc_Clr_Sem || _mlxParams.cmd == Mc_Set_Raw ||
-         _mlxParams.cmd == Mc_Backup || _mlxParams.cmd == Mc_ShowConfs || _mlxParams.cmd == Mc_Apply) &&
+         _mlxParams.cmd == Mc_Get_Raw || _mlxParams.cmd == Mc_Backup || _mlxParams.cmd == Mc_ShowConfs || 
+		 _mlxParams.cmd == Mc_Apply) &&
         _mlxParams.device.length() == 0)
     {
         return err(true, "%s command expects device to be specified.",
