@@ -45,9 +45,8 @@
 
 #include <tools_dev_types.h>
 #include <reg_access/reg_access.h>
-
+#include <tools_layouts/reg_access_switch_layouts.h>
 #include "mlxcfg_ui.h"
-#include "mlxcfg_utils.h"
 #include "mlxcfg_generic_commander.h"
 
 #define DISABLE_SLOT_POWER_LIMITER "DISABLE_SLOT_POWER_LIMITER"
@@ -289,26 +288,26 @@ int MlxCfg::printValue(string strVal, u_int32_t val)
     u_int32_t n;
     if (strVal == "" || strVal == s || (strToNum(strVal, n, 10) && n == val))
     {
-        return printf("%-16u", val);
+        return printf("%-20u", val);
     }
     if (strVal.find("Array") == string::npos)
     {
         strVal += "(" + s + ")";
     }
-    return printf("%-16s", strVal.c_str());
+    return printf("%-20s", strVal.c_str());
 }
 
 int MlxCfg::printParam(string param, u_int32_t val)
 {
     if (val == MLXCFG_UNKNOWN)
     {
-        return printf("%-16s", "N/A");
+        return printf("%-20s", "N/A");
     }
     return printValue(param, val);
 }
 
 #define PRINT_SPACE_IF_NEEDED(width) \
-    if (width > 16)                  \
+    if (width >= 20)                 \
     {                                \
         printf(" ");                 \
     }
@@ -320,15 +319,20 @@ void MlxCfg::printSingleParam(const char* name, QueryOutputItem& queryOutItem, u
     int width = 0;
     string fieldName = increaseIndexIfNeeded(name);
 
+    string diff = " ";
+    string readOnly = "  ";
+
     if ((showDefault && queryOutItem.nextVal != queryOutItem.defVal) ||
         (showCurrent && queryOutItem.nextVal != queryOutItem.currVal))
     {
-        printf("*        %-36s", fieldName.c_str());
+        diff = "*";
     }
-    else
+    if (queryOutItem.isReadOnly)
     {
-        printf("         %-36s", fieldName.c_str());
+        readOnly = "RO";
     }
+    printf("%s%s     %-44s", diff.c_str(), readOnly.c_str(), fieldName.c_str());
+
     if (showDefault)
     {
         width = printParam(queryOutItem.strDefVal, queryOutItem.defVal);
@@ -374,30 +378,30 @@ void MlxCfg::printOpening(mfile* mf, const char* dev, int devIndex)
     printf("\nDevice #%d:\n", devIndex);
     printf("----------\n\n");
     const char* devType = getDeviceName(mf);
-    printf("%-16s%-16s\n", "Device type:", devType);
+    printf("%-20s%-20s\n", "Device type:", devType);
     if (!dm_is_4th_gen(_devType))
     {
         std::vector<char> info;
         info.reserve(16);
         if (!getDeviceInformationString(mf, Device_Name, info))
         {
-            printf("%-16s%-16s\n", "Name:", "N/A");
+            printf("%-20s%-20s\n", "Name:", "N/A");
         }
         else
         {
-            printf("%-16s%-16s\n", "Name:", info.data());
+            printf("%-20s%-20s\n", "Name:", info.data());
         }
         info.clear();
         if (!getDeviceInformationString(mf, Device_Description, info))
         {
-            printf("%-16s%-16s\n", "Description:", "N/A");
+            printf("%-20s%-20s\n", "Description:", "N/A");
         }
         else
         {
-            printf("%-16s%-16s\n", "Description:", info.data());
+            printf("%-20s%-20s\n", "Description:", info.data());
         }
     }
-    printf("%-16s%-16s\n", "Device:", dev);
+    printf("%-20s%-20s\n", "Device:", dev);
 }
 
 void MlxCfg::printConfHeader(bool showDefualt, bool showNew, bool showCurrent)
@@ -407,22 +411,22 @@ void MlxCfg::printConfHeader(bool showDefualt, bool showNew, bool showCurrent)
     {
         if (showCurrent)
         {
-            printf("%-16s%36s%16s%18s", "Configurations:", "Default", "Current", NEXT_STR);
+            printf("%-20s%39s%21s%23s", "Configurations:", "Default", "Current", NEXT_STR);
         }
         else
         {
-            printf("%-16s%36s%18s", "Configurations:", "Default", NEXT_STR);
+            printf("%-20s%39s%23s", "Configurations:", "Default", NEXT_STR);
         }
     }
     else
     {
         if (showCurrent)
         {
-            printf("%-16s%36s%18s", "Configurations:", "Current", NEXT_STR);
+            printf("%-20s%41s%18s", "Configurations:", "Current", NEXT_STR);
         }
         else
         {
-            printf("%-16s%38s", "Configurations:", NEXT_STR);
+            printf("%-20s%41s", "Configurations:", NEXT_STR);
         }
     }
     if (showNew)
@@ -437,6 +441,7 @@ void prepareSetInput(vector<QueryOutputItem>& output, vector<ParamView>& params)
     {
         QueryOutputItem o;
         o.mlxconfigName = p->mlxconfigName;
+        o.isReadOnly = p->isReadOnlyParam;
         o.defVal = MLXCFG_UNKNOWN;
         o.currVal = MLXCFG_UNKNOWN;
         o.nextVal = MLXCFG_UNKNOWN;
@@ -463,6 +468,7 @@ void prepareQueryOutput(vector<QueryOutputItem>& output, vector<ParamView>& para
         {
             QueryOutputItem o;
             o.mlxconfigName = p->mlxconfigName;
+            o.isReadOnly = p->isReadOnlyParam;
             o.defVal = MLXCFG_UNKNOWN;
             o.currVal = MLXCFG_UNKNOWN;
             o.nextVal = MLXCFG_UNKNOWN;
@@ -477,12 +483,13 @@ void queryAux(Commander* commander,
               vector<ParamView>& params,
               vector<ParamView>& paramsToQuery,
               vector<string>& failedTLVs,
-              QueryType qT)
+              QueryType qT,
+              bool isWriteOperation)
 {
     if (paramsToQuery.size() != 0)
     {
         params = paramsToQuery;
-        commander->queryParamViews(params, qT);
+        commander->queryParamViews(params, isWriteOperation, qT);
     }
     else
     {
@@ -496,7 +503,10 @@ string checkFailedTLVsVector(const vector<string>& failedTLVs, string queryType)
     if (failedTLVs.size() != 0)
     {
         failedTLVsErrorMessage += "    Failed to query the " + queryType + " values of the following TLVs:\n    ";
-        CONST_VECTOR_ITERATOR(string, failedTLVs, it) { failedTLVsErrorMessage += (*it) + " "; }
+        CONST_VECTOR_ITERATOR(string, failedTLVs, it)
+        {
+            failedTLVsErrorMessage += (*it) + " ";
+        }
         failedTLVsErrorMessage += "\n";
     }
     return failedTLVsErrorMessage;
@@ -528,7 +538,6 @@ void MlxCfg::removeContinuanceArray(std::vector<QueryOutputItem>& OutputItemOut,
                                     std::vector<QueryOutputItem>& OutputItemIn)
 {
     QueryOutputItem* queryItem = NULL;
-    ;
     u_int32_t arrayCounter = 0;
 
     VECTOR_ITERATOR(QueryOutputItem, OutputItemIn, o)
@@ -566,13 +575,19 @@ void MlxCfg::removeContinuanceArray(std::vector<QueryOutputItem>& OutputItemOut,
     }
 }
 
-mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander, const char* dev, const char* pci, int devIndex, bool printNewCfg)
+mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander,
+                                 const char* dev,
+                                 bool isWriteOperation,
+                                 const char* pci,
+                                 int devIndex,
+                                 bool printNewCfg)
 {
     (void)pci;
     std::vector<QueryOutputItem> output;
     std::vector<QueryOutputItem> newoutput;
     std::vector<ParamView> params, defaultParams, currentParams;
     bool failedToGetCfg = false, isParamsDiffer = false;
+    bool isParamsReadOnly = false;
     bool defaultSupported = false, currentSupported = false;
     bool showDefault = false, showCurrent = false;
 
@@ -603,19 +618,22 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander, const char* dev, const ch
 
         if (printNewCfg)
         {
-            VECTOR_ITERATOR(ParamView, _mlxParams.setParams, p) { commander->updateParamViewValue(*p, p->setVal); }
+            VECTOR_ITERATOR(ParamView, _mlxParams.setParams, p)
+            {
+                commander->updateParamViewValue(*p, p->setVal);
+            }
             prepareSetInput(output, _mlxParams.setParams);
         }
 
         if (showDefault)
         {
-            queryAux(commander, defaultParams, _mlxParams.setParams, defaultFailedTLVs, QueryDefault);
+            queryAux(commander, defaultParams, _mlxParams.setParams, defaultFailedTLVs, QueryDefault, isWriteOperation);
         }
         if (showCurrent)
         {
-            queryAux(commander, currentParams, _mlxParams.setParams, currentFailedTLVs, QueryCurrent);
+            queryAux(commander, currentParams, _mlxParams.setParams, currentFailedTLVs, QueryCurrent, isWriteOperation);
         }
-        queryAux(commander, params, _mlxParams.setParams, nextFailedTLVs, QueryNext);
+        queryAux(commander, params, _mlxParams.setParams, nextFailedTLVs, QueryNext, isWriteOperation);
     }
     catch (MlxcfgException& e)
     {
@@ -644,6 +662,7 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander, const char* dev, const ch
           QUERY_NEXT_MASK | (showDefault ? QUERY_DEFAULT_MASK : 0) | (showCurrent ? QUERY_CURRENT_MASK : 0),
           printNewCfg);
         isParamsDiffer |= (showDefault && (o->nextVal != o->defVal)) || (showCurrent && (o->nextVal != o->currVal));
+        isParamsReadOnly |= o->isReadOnly;
     }
 
     string failedTLVsErrorMessage = "Failed to query some of the TLVs:\n";
@@ -656,6 +675,10 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander, const char* dev, const ch
         printf("The '*' shows parameters with next value different "
                "from default/current value.\n");
     }
+    if (isParamsReadOnly)
+    {
+        printf("\nThe 'RO' shows parameters which are for read only and cannot be changed\n");
+    }
 
     if (_mlxParams.enableVerbosity)
     {
@@ -692,6 +715,7 @@ mlxCfgStatus MlxCfg::queryDevCfg(const char* dev, const char* pci, int devIndex,
 {
     mlxCfgStatus rc;
     Commander* commander = NULL;
+    bool isWriteOperation = false;
     try
     {
         commander = Commander::create(string(dev), _mlxParams.dbName);
@@ -702,7 +726,7 @@ mlxCfgStatus MlxCfg::queryDevCfg(const char* dev, const char* pci, int devIndex,
         return err(false, "%s", e._err.c_str());
     }
 
-    rc = queryDevCfg(commander, dev, pci, devIndex, printNewCfg);
+    rc = queryDevCfg(commander, dev, isWriteOperation, pci, devIndex, printNewCfg);
     delete commander;
     return rc;
 }
@@ -722,6 +746,7 @@ const char* MlxCfg::getConfigWarning(const string& mlx_config_name, const string
 mlxCfgStatus MlxCfg::setDevCfg()
 {
     Commander* commander = NULL;
+    bool isWriteOperation = true;
 
     try
     {
@@ -750,7 +775,7 @@ mlxCfgStatus MlxCfg::setDevCfg()
         }
     }
 
-    if (queryDevCfg(commander, _mlxParams.device.c_str(), NULL, 1, true) == MLX_CFG_ERROR_EXIT)
+    if (queryDevCfg(commander, _mlxParams.device.c_str(), isWriteOperation, NULL, 1, true) == MLX_CFG_ERROR_EXIT)
     {
         delete commander;
         printErr();
@@ -1041,6 +1066,8 @@ mlxCfgStatus MlxCfg::backupCfg()
 
         for (std::vector<BackupView>::iterator it = views.begin(); it != views.end(); it++)
         {
+            // u_int32_t tlvType = it->type_index;
+            // tlvType += it->type_class << 24;
             fprintf(file,
                     "%% TLV Type: 0x%08x, Writer ID: %s(0x%02x)"
                     ", Writer Host ID: 0x%02x\n",
@@ -1178,7 +1205,10 @@ mlxCfgStatus MlxCfg::readNVInputFile(string& content)
         return rc;
     }
 
-    VECTOR_ITERATOR(string, lines, l) { content += *l; }
+    VECTOR_ITERATOR(string, lines, l)
+    {
+        content += *l;
+    }
     return MLX_CFG_OK;
 }
 
@@ -1218,7 +1248,10 @@ mlxCfgStatus MlxCfg::writeNVOutputFile(string content)
 mlxCfgStatus MlxCfg::writeNVOutputFile(vector<string> lines)
 {
     string content;
-    VECTOR_ITERATOR(string, lines, l) { content += *l; }
+    VECTOR_ITERATOR(string, lines, l)
+    {
+        content += *l;
+    }
     return writeNVOutputFile(content);
 }
 
@@ -1454,7 +1487,7 @@ mlxCfgStatus MlxCfg::createConf()
     return MLX_CFG_ERROR_EXIT;
 #else
     string xml;
-    vector<u_int32_t> buff;
+    vector < u_int32_t > buff;
     mlxCfgStatus rc = MLX_CFG_OK;
 
     rc = readNVInputFile(xml);
@@ -1465,21 +1498,16 @@ mlxCfgStatus MlxCfg::createConf()
         GenericCommander commander(NULL, _mlxParams.dbName, _mlxParams.deviceType == Switch);
         commander.createConf(xml, buff);
 
-        if (!_mlxParams.privPemFile.empty() && !_mlxParams.keyPairUUID.empty())
-        {
+        if (!_mlxParams.privPemFile.empty() && !_mlxParams.keyPairUUID.empty()) {
             commander.sign(buff, _mlxParams.privPemFile, _mlxParams.keyPairUUID, "", "");
-        }
-        else if (!_mlxParams.opensslEngine.empty() && !_mlxParams.opensslKeyId.empty() &&
-                 !_mlxParams.keyPairUUID.empty())
-        {
+        } else if (!_mlxParams.opensslEngine.empty() && !_mlxParams.opensslKeyId.empty() &&
+                   !_mlxParams.keyPairUUID.empty()) {
             commander.sign(buff, "", _mlxParams.keyPairUUID, _mlxParams.opensslEngine, _mlxParams.opensslKeyId);
-        }
-        else
-        {
+        } else {
             commander.sign(buff);
         }
     }
-    catch (MlxcfgException& e)
+    catch(MlxcfgException & e)
     {
         printf("-E- %s\n", e._err.c_str());
         rc = MLX_CFG_ERROR;
