@@ -45,9 +45,6 @@
 #define IDENT3 "\t\t"
 #define IDENT4 IDENT2 IDENT
 
-#define FIFTH_GENERATION_LIST "Connect-IB/Connect-X4/LX"
-#define FOURTH_GENERATION_LIST "ConnectX3/Pro"
-
 #include <string>
 #include <vector>
 
@@ -92,6 +89,14 @@ enum RawTlvMode
     GET_RAW
 };
 
+typedef enum
+{
+    UNSUPPORTED_DEVICE = -1,
+    HCA = 0,
+    Switch = 1,
+    LinkX = 2
+} Device_Type;
+
 #define VECTOR_ITERATOR(t, v, i) for (vector<t>::iterator i = v.begin(); i != v.end(); ++i)
 
 #define CONST_VECTOR_ITERATOR(t, v, i) for (vector<t>::const_iterator i = v.begin(); i != v.end(); ++i)
@@ -111,7 +116,7 @@ enum RawTlvMode
 /*
  * Debug print MACRO of the NV Tlvs:
  */
-//#define _ENABLE_DEBUG_
+// #define _ENABLE_DEBUG_
 #ifdef _ENABLE_DEBUG_
 #define DEBUG_PRINT_SEND(data_struct, struct_name) \
     printf("-I- Data Sent:\n");                    \
@@ -154,6 +159,7 @@ MError nvdiCom5thGen(mfile* mf, u_int32_t tlvType);
 bool strToNum(std::string str, u_int32_t& num, int base = 0);
 
 std::string numToStr(u_int32_t num, bool isHex = false);
+std::string numToStrFormatted(u_int32_t num, bool isHex = false);
 
 vector<string> splitStr(const string s, char d);
 
@@ -189,6 +195,8 @@ string getArrayPrefix(const string& mlxconfigName);
 
 bool getDeviceInformationString(mfile* mf, info_type_t op, vector<char>& infoString);
 
+Device_Type getDeviceTypeFromString(string inStr);
+
 class MlxcfgException : public exception
 {
 public:
