@@ -204,7 +204,7 @@ using namespace std;
 #define CHECKB2(b, o, n, f, p, fp)          \
     do                                      \
     {                                       \
-        if (!checkBoot2(b, o, n, f, p, fp)) \
+        if (!CheckBoot2(b, o, n, f, p, fp)) \
         {                                   \
             return false;                   \
         }                                   \
@@ -212,7 +212,7 @@ using namespace std;
 #define FS3_CHECKB2(b, o, f, p, i)         \
     {                                      \
         u_int32_t n;                       \
-        if (!checkBoot2(b, o, n, f, p, i)) \
+        if (!CheckBoot2(b, o, n, f, p, i)) \
         {                                  \
             return false;                  \
         }                                  \
@@ -358,7 +358,7 @@ typedef enum fs3_section
     FS3_FW_BOOT_CFG = 0x11,
     FS3_FW_MAIN_CFG = 0x12,
     FS3_APU_KERNEL = 0x14,
-    FS3_APU_APPS = 0x15,
+    FS3_ACE_CODE = 0x15,
     FS3_ROM_CODE = 0x18,
     FS3_RESET_INFO = 0x20,
     FS3_DBG_FW_INI = 0x30,
@@ -377,6 +377,8 @@ typedef enum fs3_section
     FS4_RSA_PUBLIC_KEY = 0xa6,
     FS4_RSA_4096_SIGNATURES = 0xa7,
     FS4_EXCLKSYNC_INFO = 0xb0,
+    FS4_MAIN_HASHES_PAGES = 0xb1,
+    FS4_MAIN_LOCKED_HASHES_PAGES = 0xb2,
     FS3_MFG_INFO = 0xe0,
     FS3_DEV_INFO = 0xe1,
     FS3_NV_DATA1 = 0xe2,
@@ -397,6 +399,10 @@ typedef enum fs3_section
     FS4_LC_INI_NV_DATA = 0xf1,
     FS4_CERT_CHAIN_0 = 0xf2,
     FS4_DIGITAL_CACERT_RW = 0xf3,
+    FS4_CERTIFICATE_CHAINS_1 = 0xf4,
+    FS4_CERTIFICATE_CHAINS_2 = 0xf5,
+    FS4_ROOT_CERTIFICATES_1 = 0xf6,
+    FS4_ROOT_CERTIFICATES_2 = 0xf7,
     FS4_HASHES_TABLE = 0xfa,
     FS4_HW_PTR = 0xfb,
     FS4_TOOLS_AREA = 0xfc,
