@@ -35,7 +35,6 @@
 #include "aux_tlv_ops.h"
 #include "fw_comps_mgr/fw_comps_mgr.h"
 #include "fw_comps_mgr/fw_comps_mgr_dma_access.h"
-#include "tools_layouts/image_layout_layouts.h"
 
 class FsCtrlOperations : public FwOperations
 {
@@ -49,6 +48,7 @@ public:
     virtual ~FsCtrlOperations();
 
     virtual u_int8_t FwType();
+    virtual bool IsFifthGen() { return true; }
 
     virtual bool FwQuery(fw_info_t* fwInfo,
                          bool readRom = true,
@@ -76,6 +76,7 @@ public:
     virtual bool
       FwBurn(FwOperations* imageOps, u_int8_t forceVersion, ProgressCallBack progressFunc = (ProgressCallBack)NULL);
     virtual bool FwBurnAdvanced(FwOperations* imageOps, ExtBurnParams& burnParams);
+    virtual bool FwBurnAdvanced(FwOperations* imageOps, ExtBurnParams& burnParams, FwComponent::comps_ids_t ComponentId);
     virtual bool FwBurnAdvanced(std::vector<u_int8_t> imageOps4MData,
                                 ExtBurnParams& burnParams,
                                 FwComponent::comps_ids_t ComponentId = FwComponent::COMPID_BOOT_IMG);
@@ -110,12 +111,9 @@ public:
                                   struct tools_open_fw_version& fwVer,
                                   bool queryRunning = false);
     virtual bool FwResetTimeStamp();
-    virtual u_int32_t GetHwDevId() { return _hwDevId; }
     bool FwReactivateImage();
     Tlv_Status_t GetTsObj(TimeStampIFC** tsObj);
     bool isEncrypted(bool& is_encrypted);
-    bool getITOCAddr(u_int32_t& addr);
-    bool CheckITOCSignature(u_int8_t* signature);
     bool burnEncryptedImage(FwOperations* imageOps, ExtBurnParams& burnParams);
 
     virtual bool IsFsCtrlOperations() { return true; }
@@ -125,8 +123,11 @@ public:
     virtual bool IsLifeCycleSupported();
     virtual bool IsEncryptionSupported();
     virtual bool IsSecurityVersionViolated(u_int32_t image_security_version);
+    bool GetHashesTableData(vector<u_int8_t>& data);
+    virtual bool QueryComponentData(FwComponent::comps_ids_t comp, u_int32_t deviceIndex, vector<u_int8_t>& data);
 
-protected:
+private:
+    virtual u_int32_t GetHwDevId() { return _hwDevId; }
     bool FsIntQuery();
     bool GetImageInfo(u_int8_t* buff);
     bool ReadBootImage(void* image,
@@ -138,10 +139,14 @@ protected:
     virtual bool VerifyAllowedParams(ExtBurnParams& burnParams, bool isSecure);
     bool BadParamErrMsg(const char* unSupportedOperation, bool isSecure);
     bool _Burn(std::vector<u_int8_t> imageOps4MData,
-               ExtBurnParams& burnParams,
+               ProgressCallBackAdvSt& progressCallBack,
                FwComponent::comps_ids_t ComponentId = FwComponent::COMPID_BOOT_IMG);
     bool _createImageOps(FwOperations** imgOps);
     void ExtractSwitchFWVersion(const fwInfoT& fwQuery);
+    bool GetHWPointers(image_layout_hw_pointers_carmel& hw_pointers);
+    bool CheckITOCSignature(u_int8_t* signature);
+    bool GetHashesTableAddr(u_int32_t& addr);
+    bool GetHashesTableSize(u_int32_t hashes_table_addr, u_int32_t& size);
 
     fs3_info_t _fsCtrlImgInfo;
     FwCompsMgr* _fwCompsAccess;
