@@ -1,5 +1,6 @@
 /*
  * Copyright (C) Jan 2020 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -48,20 +49,18 @@
 #define MLXFWOP_API
 #endif
 
-const std::string DIFFERENT_BRANCHES_EXCEPTION =
-        "Trying to compare different branches is invalid";
+const std::string DIFFERENT_BRANCHES_EXCEPTION = "Trying to compare different branches is invalid";
 const std::string NOT_SET_VERSION = "";
 const unsigned short MAX_VERSION_LENGTH = 28;
 
-class FwVersionException: public std::runtime_error {
+class FwVersionException : public std::runtime_error
+{
 public:
-    FwVersionException() :
-            std::runtime_error(DIFFERENT_BRANCHES_EXCEPTION) {
-    }
+    FwVersionException() : std::runtime_error(DIFFERENT_BRANCHES_EXCEPTION) {}
 };
 
-
-class MLXFWOP_API FwVersion {
+class MLXFWOP_API FwVersion
+{
     /*
      * Using MGIR command, when a given FW binary has non-zero value in
      * DEVELOPMENT_INFO, it shall be treated as a development branch file.
@@ -71,37 +70,37 @@ class MLXFWOP_API FwVersion {
      */
 public:
     FwVersion();
-    FwVersion(unsigned short int, unsigned short int, unsigned short int,
-            const std::string& = "");
+    FwVersion(unsigned short int, unsigned short int, unsigned short int, const std::string& = "");
     virtual ~FwVersion();
     FwVersion(const FwVersion&);
     FwVersion& operator=(const FwVersion&);
     bool operator==(const FwVersion&) const;
     bool operator!=(const FwVersion&) const;
-    bool operator>(const FwVersion &) const;
-    bool operator<(const FwVersion &) const;
-    bool operator>=(const FwVersion &) const;
-    bool operator<=(const FwVersion &) const;
+    bool operator>(const FwVersion&) const;
+    bool operator<(const FwVersion&) const;
+    bool operator>=(const FwVersion&) const;
+    bool operator<=(const FwVersion&) const;
     std::string get() const;
     friend std::ostream& operator<<(std::ostream&, const FwVersion&);
     std::string get_fw_version(const std::string& master_format = "%d.%d.%d",
-            bool even_subminor = false,
-            const std::string& not_set = NOT_SET_VERSION) const;
+                               bool even_subminor = false,
+                               const std::string& not_set = NOT_SET_VERSION) const;
     bool is_set() const;
     bool are_same_branch(const FwVersion&) const;
     int compare_master_version(const FwVersion&) const;
     int compare(const FwVersion&) const;
     virtual FwVersion* clone() const;
+
 protected:
     unsigned short int _major;
     unsigned short int _minor;
     unsigned short int _subminor;
     std::string _devBranchTag;
-    virtual std::string get_master_version(const std::string& format,
-            bool even_subminor = false) const;
+    virtual std::string get_master_version(const std::string& format, bool even_subminor = false) const;
+
 private:
     bool is_master_branch() const;
-    bool is_Switch() const;
+    bool is_switch_or_gb() const;
     /*
      * currently we have 3 FW version format
      * 0: MM.mm.ssss
@@ -117,4 +116,37 @@ private:
     int get_master_format() const;
 };
 
+class MLXFWOP_API ComponentFwVersion
+{
+public:
+    ComponentFwVersion();
+    ComponentFwVersion(unsigned short int, unsigned short int);
+    ComponentFwVersion(const ComponentFwVersion&);
+    ComponentFwVersion& operator=(const ComponentFwVersion&);
+
+    std::string ToString();
+    bool operator==(const ComponentFwVersion&) const;
+    bool operator!=(const ComponentFwVersion&) const;
+    bool operator>(const ComponentFwVersion&) const;
+    bool operator<(const ComponentFwVersion&) const;
+    bool operator>=(const ComponentFwVersion&) const;
+    bool operator<=(const ComponentFwVersion&) const;
+
+private:
+    int Compare(const ComponentFwVersion&) const;
+
+    enum class VersionFormat : int
+    {
+        None = 0,
+        Major = 1,
+        Minor = 2,
+        SubMinor = 3
+    };
+
+    unsigned short int _major;
+    unsigned short int _minor;
+    unsigned short int _subMinor;
+    VersionFormat _format;
+};
+
 #endif /* MLXFWOPS_LIB_FW_VERSION_H_ */
