@@ -67,6 +67,7 @@
 #define SPECTRUM3_HW_ID 592
 #define QUANTUM2_HW_ID 599
 #define QUANTUM3_HW_ID 603
+#define ARCUSE_HW_ID 45568
 #define SPECTRUM4_HW_ID 596
 #define GEARBOX_HW_ID 594
 #define GB_MANAGER_HW_ID 595
@@ -314,7 +315,8 @@ typedef enum chip_type
     CT_SPECTRUM4,
     CT_GEARBOX,
     CT_GEARBOX_MGR,
-    CT_ABIR_GEARBOX
+    CT_ABIR_GEARBOX,
+    CT_ARCUSE
 } chip_type_t;
 
 #define IS_HCA(chipType)                                                                                 \
@@ -345,12 +347,12 @@ typedef struct fs3_uid
     int base_guid_specified;
     guid_t base_mac;
     int base_mac_specified;
-    u_int8_t num_of_guids;       // set 0 for default
-    u_int8_t step_size;          // set 0 for default, not relevant for devices >= CX4
-    int set_mac_from_guid;       // if set , base_mac will be derrived automatically from base guid
-    int use_pp_attr;             // if set, num_of_guids[2] and step_size[2] will be used for the uid attributes.
-    u_int8_t num_of_guids_pp[2]; // set 0xff for default
-    u_int8_t step_size_pp[2];    // set 0xff for default, not relevant for devices >= CX4
+    u_int8_t num_of_guids;        // set 0 for default
+    u_int8_t step_size;           // set 0 for default, not relevant for devices >= CX4
+    int set_mac_from_guid;        // if set , base_mac will be derrived automatically from base guid
+    int use_pp_attr;              // if set, num_of_guids[2] and step_size[2] will be used for the uid attributes.
+    u_int16_t num_of_guids_pp[2]; // set 0xffff for default
+    u_int8_t step_size_pp[2];     // set 0xff for default, not relevant for devices >= CX4
 } fs3_uid_t;
 
 typedef struct fs4_uid
@@ -386,6 +388,14 @@ struct fs3_uid_entry
     u_int64_t uid;
 };
 
+struct fs4_uid_entry
+{
+    u_int8_t num_allocated;
+    u_int8_t step; // not relevant for devices >= CX4
+    u_int8_t num_allocated_msb;
+    u_int64_t uid;
+};
+
 typedef struct cibfw_uids
 {
     struct fs3_uid_entry guids[2];
@@ -398,13 +408,20 @@ typedef struct cx4fw_uids
     struct fs3_uid_entry base_mac;
 } cx4_uids_t;
 
+typedef struct
+{
+    struct fs4_uid_entry base_guid;
+    struct fs4_uid_entry base_mac;
+} image_layout_uids_t;
+
 typedef struct uids
 {
-    int valid_field; // 0: cib_uids , 1: cx4_uids
+    int valid_field; // 0: cib_uids , 1: image_layout_uids
     union
     {
         cib_uids_t cib_uids;
-        cx4_uids_t cx4_uids;
+        cx4_uids_t cx4_uids; // keeping this member for neohost
+        image_layout_uids_t image_layout_uids;
     };
 } uids_t;
 
@@ -539,6 +556,8 @@ typedef enum fw_img_type
     FIT_FC1 = 2,
     FIT_FS4 = 3,
     FIT_FSCTRL = 4,
+    FIT_FS5 = 5,
+    FIT_COMPS = 6
 } fw_img_type_t;
 
 enum ExpRomProto
