@@ -32,8 +32,6 @@
 #ifndef MLXLINK_CABLES_COMMANDER_H
 #define MLXLINK_CABLES_COMMANDER_H
 
-//#include "mlxlink_utils.h"
-//#include <mtcr.h>
 #include "mlxlink_reg_parser.h"
 
 typedef struct
@@ -137,7 +135,6 @@ public:
     u_int32_t _cableIdentifier;
     bool _sfp51Paging;
     bool _passiveQsfp;
-    u_int32_t _localPort;
     u_int32_t _numOfLanes;
     MlxlinkMaps* _mlxlinkMaps;
     map<ModulePrbs_t, string> _modulePrbsParams;
@@ -200,7 +197,7 @@ private:
     u_int32_t pmcrStrToValue(ControlParam paramId, const string& value);
     string getPMCRCapValueStr(u_int32_t valueCap, ControlParam paramId);
     void checkPMCRFieldsCap(vector<pair<ControlParam, string>>& params);
-    void buildPMCRRequest(ControlParam paramId, const string& value);
+    string buildPMCRRequest(ControlParam paramId, const string& value);
 
     Json::Value& _jsonRoot;
     vector<page_t> _validPages;
