@@ -70,6 +70,19 @@ string deleteLastChar(const string& s, u_int32_t numOfCharsToRemove)
     return newStr;
 }
 
+float convertFloatPrec(float value)
+{
+    string s;
+    char strVal[32];
+    float res;
+    u_int32_t prec = 3;
+
+    snprintf(strVal, sizeof(strVal), "%.*f", prec, value);
+    res = stof(string(strVal));
+
+    return res;
+}
+
 string getStringFromVector(vector<string> values)
 {
     string s;
@@ -87,7 +100,7 @@ string getStringFromVector(vector<float> values)
     u_int32_t prec = 0;
     for (vector<float>::const_iterator i = values.begin(); i != values.end(); ++i)
     {
-        if ((*i - ((int)*i)) > 0)
+        if (abs((*i - ((int)*i))) > 0)
         {
             prec = 3;
         }
@@ -176,6 +189,10 @@ string IBSupportedSpeeds2Str(u_int32_t mask)
 {
     string maskStr = "";
 
+    if (mask & IB_LINK_SPEED_XDR)
+    {
+        maskStr += "XDR,";
+    }
     if (mask & IB_LINK_SPEED_NDR)
     {
         maskStr += "NDR,";
@@ -349,11 +366,18 @@ string EthExtSupportedSpeeds2Str(u_int32_t int_mask)
 
 string SupportedSpeeds2Str(u_int32_t proto_active, u_int32_t mask, bool extended)
 {
-    if (extended && proto_active == ETH)
+    switch (proto_active)
     {
-        return EthExtSupportedSpeeds2Str(mask);
+        case IB:
+            return IBSupportedSpeeds2Str(mask);
+        case ETH:
+            if (extended)
+            {
+                return EthExtSupportedSpeeds2Str(mask);
+            }
     }
-    return proto_active == IB ? IBSupportedSpeeds2Str(mask) : EthSupportedSpeeds2Str(mask);
+
+    return EthSupportedSpeeds2Str(mask);
 }
 
 string getOui(u_int32_t oui)
@@ -580,6 +604,10 @@ int ptysSpeedToMaskIB(const string& speed)
     {
         return IB_LINK_SPEED_NDR;
     }
+    if (speed == "XDR")
+    {
+        return IB_LINK_SPEED_XDR;
+    }
     return 0x0;
 }
 
@@ -596,7 +624,7 @@ bool isPAM4Speed(u_int32_t activeSpeed, u_int32_t protoActive, bool extended)
     }
     else if (protoActive == IB)
     {
-        if (activeSpeed == IB_LINK_SPEED_HDR || activeSpeed == IB_LINK_SPEED_NDR)
+        if (activeSpeed == IB_LINK_SPEED_HDR || activeSpeed == IB_LINK_SPEED_NDR || activeSpeed == IB_LINK_SPEED_XDR)
         {
             pam4Signal = true;
         }
@@ -696,55 +724,6 @@ bool checkPplrCmd(const string& pplrCmd)
     return true;
 }
 
-string prbsMaskToLaneRate(u_int32_t mask)
-{
-    if (mask == PRBS_SDR)
-    {
-        return "2.5G";
-    }
-    if (mask == PRBS_DDR)
-    {
-        return "5G";
-    }
-    if (mask == PRBS_QDR)
-    {
-        return "10G";
-    }
-    if (mask == PRBS_FDR10)
-    {
-        return "10.3125G";
-    }
-    if (mask == PRBS_FDR)
-    {
-        return "14.0625G";
-    }
-    if (mask == PRBS_EDR)
-    {
-        return "25.78125G";
-    }
-    if (mask == PRBS_HDR)
-    {
-        return "53.125G";
-    }
-    if (mask == PRBS_NDR)
-    {
-        return "106.25G";
-    }
-    if (mask == PRBS_1G)
-    {
-        return "1.25G";
-    }
-    if (mask == PRBS_XAUI)
-    {
-        return "3.125G";
-    }
-    if (mask == PRBS_50G)
-    {
-        return "12.89G";
-    }
-    return "N/A";
-}
-
 u_int32_t prbsMaskToRateNum(u_int32_t mask)
 {
     if (mask == PRBS_SDR)
@@ -779,6 +758,10 @@ u_int32_t prbsMaskToRateNum(u_int32_t mask)
     {
         return 400;
     }
+    if (mask == PRBS_XDR)
+    {
+        return 800;
+    }
     if (mask == PRBS_1G)
     {
         return 1;
@@ -794,83 +777,6 @@ u_int32_t prbsMaskToRateNum(u_int32_t mask)
     return 0;
 }
 
-bool prbsLaneRateCheck(const string& rate)
-{
-    if (rate == "SDR" || rate == "IB-SDR")
-    {
-        return true;
-    }
-    if (rate == "DDR" || rate == "IB-DDR" || rate == "5G")
-    {
-        return true;
-    }
-    if (rate == "QDR" || rate == "IB-QDR")
-    {
-        return true;
-    }
-    if (rate == "FDR10" || rate == "IB-FDR10" || rate == "10G" || rate == "40G")
-    {
-        return true;
-    }
-    if (rate == "FDR" || rate == "IB-FDR" || rate == "14G")
-    {
-        return true;
-    }
-    if (rate == "EDR" || rate == "IB-EDR" || rate == "25G" || rate == "50G" || rate == "100G" || rate == "50G_2X" ||
-        rate == "100G_4X")
-    {
-        return true;
-    }
-    if (rate == "HDR" || rate == "IB-HDR" || rate == "200G_4X" || rate == "50G_1X" || rate == "100G_2X" ||
-        rate == "400G_8X")
-    {
-        return true;
-    }
-    if (rate == "NDR" || rate == "IB-NDR" || rate == "100G_1X" || rate == "200G_2X" || rate == "400G_4X" ||
-        rate == "800G_8X")
-    {
-        return true;
-    }
-    if (rate == "1G")
-    {
-        return true;
-    }
-    if (rate == "XAUI" || rate == "2.5G")
-    {
-        return true;
-    }
-    if (rate == "50GE-KR4" || rate == "12.89G")
-    {
-        return true;
-    }
-    if (rate == "")
-    {
-        return true;
-    }
-    return false;
-}
-
-string prbsMaskToTuningStatus(u_int32_t mask)
-{
-    if (mask == PRBS_TUNING_NOT_PERFORMED)
-    {
-        return "PRBS mode tuning was not performed.";
-    }
-    if (mask == PRBS_TUNING_PERFORMING)
-    {
-        return "Performing PRBS mode tuning.";
-    }
-    if (mask == PRBS_TUNING_COMPLETE)
-    {
-        return "PRBS mode tuning completed.";
-    }
-    if (mask == PRBS_SIGNAL_DETECT)
-    {
-        return "Signal Detect in progress.";
-    }
-    return "N/A";
-}
-
 string prbsMaskToLockStatus(u_int32_t mask, u_int32_t numOfLanesToUse)
 {
     string res = "";
@@ -1080,13 +986,27 @@ string getTemp(u_int32_t temp, int celsParam)
     return to_string(temp / celsParam);
 }
 
-float getPower(u_int16_t power)
+float getPower(u_int16_t power, bool isModuleExtSupported)
 {
-    if (power & 0x8000)
+    double result = -40;
+
+    if (isModuleExtSupported)
     {
-        return -((~power & 0xFFFF) + 1);
+        if (power != 0)
+        {
+            result = 10 * log10(float(power) / 1000.0);
+        }
+
+        return result;
+    }
+    else
+    {
+        if (power & 0x8000)
+        {
+            return -((~power & 0xFFFF) + 1);
+        }
+        return power;
     }
-    return power;
 }
 
 int getHeight(u_int16_t height)
@@ -1257,7 +1177,7 @@ string getCompliance(u_int32_t compliance, std::map<u_int32_t, std::string> comp
     return compliance_str;
 }
 
-string getFwVersion(bool passive, u_int32_t moduleFWVer)
+string getModuleFwVersion(bool passive, u_int32_t moduleFWVer)
 {
     string moduleFWVersion = "N/A";
     if (!passive)
@@ -1349,6 +1269,26 @@ double mw_to_dbm(double x)
     return 10 * log10(x);
 }
 
+string floatToStr(float num, int resolution)
+{
+    char fmt[32];
+
+    if (!(num - static_cast<int>(num)))
+    {
+        snprintf(fmt, sizeof(fmt), "%.0f", num);
+    }
+    else if (resolution < 0)
+    {
+        snprintf(fmt, sizeof(fmt), "%f", num);
+    }
+    else
+    {
+        snprintf(fmt, sizeof(fmt), "%.*f", resolution, num);
+    }
+
+    return string(fmt);
+}
+
 int readSigned(u_int32_t value, u_int32_t fieldSize)
 {
     u_int32_t signMask = (u_int32_t)pow(2.0, (1.0 * fieldSize) - 1);
@@ -1383,6 +1323,22 @@ void setPrintVal(MlxlinkCmdPrint& mlxlinkCmdPrint,
     mlxlinkCmdPrint.lastInsertedRow++;
 }
 
+int getPrintRowIndex(MlxlinkCmdPrint& mlxlinkCmdPrint, const string& key)
+{
+    int recordIndex = 0;
+
+    for (const auto& record : mlxlinkCmdPrint.mlxlinkRecords)
+    {
+        if (record.key == key)
+        {
+            break;
+        }
+        recordIndex++;
+    }
+
+    return recordIndex;
+}
+
 void setPrintTitle(MlxlinkCmdPrint& mlxlinkCmdPrint, string title, u_int32_t size, bool print)
 {
     mlxlinkCmdPrint.title = title;
@@ -1392,43 +1348,97 @@ void setPrintTitle(MlxlinkCmdPrint& mlxlinkCmdPrint, string title, u_int32_t siz
 
 bool isSpeed25GPerLane(u_int32_t speed, u_int32_t protocol)
 {
-    bool valid = true;
-    if ((protocol == IB && speed != IB_LINK_SPEED_EDR) ||
-        (protocol == ETH &&
-         (speed != ETH_LINK_SPEED_100G_CR4 && speed != ETH_LINK_SPEED_100G_KR4 && speed != ETH_LINK_SPEED_100G_LR4 &&
-          speed != ETH_LINK_SPEED_100G_SR4 && speed != ETH_LINK_SPEED_50G_KR2 && speed != ETH_LINK_SPEED_50G_SR2 &&
-          speed != ETH_LINK_SPEED_50G_CR2 && speed != ETH_LINK_SPEED_25G_CR && speed != ETH_LINK_SPEED_25G_KR &&
-          speed != ETH_LINK_SPEED_25G_SR && speed != ETH_LINK_SPEED_50G_KR4)))
+    bool valid = false;
+
+    if (protocol == IB)
     {
-        valid = false;
+        if (speed == IB_LINK_SPEED_EDR)
+        {
+            valid = true;
+        }
     }
+    else if (protocol == ETH)
+    {
+        if (speed == ETH_LINK_SPEED_100G_CR4 || speed == ETH_LINK_SPEED_100G_KR4 || speed == ETH_LINK_SPEED_100G_LR4 ||
+            speed == ETH_LINK_SPEED_100G_SR4 || speed == ETH_LINK_SPEED_50G_KR2 || speed == ETH_LINK_SPEED_50G_SR2 ||
+            speed == ETH_LINK_SPEED_50G_CR2 || speed == ETH_LINK_SPEED_25G_CR || speed == ETH_LINK_SPEED_25G_KR ||
+            speed == ETH_LINK_SPEED_25G_SR || speed == ETH_LINK_SPEED_50G_KR4)
+        {
+            valid = true;
+        }
+    }
+
     return valid;
 }
 
 bool isSpeed50GPerLane(u_int32_t speed, u_int32_t protocol)
 {
-    bool valid = true;
-    if ((protocol == IB && speed != IB_LINK_SPEED_HDR) ||
-        (protocol == ETH && (speed != ETH_LINK_SPEED_EXT_50GAUI_1 && speed != ETH_LINK_SPEED_EXT_100GAUI_2 &&
-                             speed != ETH_LINK_SPEED_EXT_200GAUI_4 && speed != ETH_LINK_SPEED_EXT_400GAUI_8)))
+    bool valid = false;
+
+    if (protocol == IB)
     {
-        valid = false;
+        if (speed == IB_LINK_SPEED_HDR)
+        {
+            valid = true;
+        }
     }
+    else if (protocol == ETH)
+    {
+        if (speed == ETH_LINK_SPEED_EXT_50GAUI_1 || speed == ETH_LINK_SPEED_EXT_100GAUI_2 ||
+            speed == ETH_LINK_SPEED_EXT_200GAUI_4 || speed == ETH_LINK_SPEED_EXT_400GAUI_8)
+        {
+            valid = true;
+        }
+    }
+
     return valid;
 }
 
 bool isSpeed100GPerLane(u_int32_t speed, u_int32_t protocol)
 {
-    bool valid = true;
-    if ((protocol == IB && speed != IB_LINK_SPEED_NDR) ||
-        (protocol == ETH && (speed != ETH_LINK_SPEED_EXT_100GAUI_1 && speed != ETH_LINK_SPEED_EXT_200GAUI_2 &&
-                             speed != ETH_LINK_SPEED_EXT_400GAUI_4)))
+    bool valid = false;
+
+    if (protocol == IB)
     {
-        valid = false;
+        if (speed == IB_LINK_SPEED_NDR)
+        {
+            valid = true;
+        }
     }
+    else if (protocol == ETH)
+    {
+        if (speed == ETH_LINK_SPEED_EXT_100GAUI_1 || speed == ETH_LINK_SPEED_EXT_200GAUI_2 ||
+            speed == ETH_LINK_SPEED_EXT_400GAUI_4 || speed == ETH_LINK_SPEED_EXT_800GAUI_8)
+        {
+            valid = true;
+        }
+    }
+
     return valid;
 }
 
+bool isSpeed200GPerLane(u_int32_t speed, u_int32_t protocol)
+{
+    bool valid = false;
+
+    if (protocol == IB)
+    {
+        if (speed == IB_LINK_SPEED_XDR)
+        {
+            valid = true;
+        }
+    }
+
+    return valid;
+}
+
+bool isNRZSpeed(u_int32_t speed, u_int32_t protocol)
+{
+    return isSpeed25GPerLane(speed, protocol) ||
+           !(isSpeed50GPerLane(speed, protocol) || isSpeed100GPerLane(speed, protocol) ||
+             isSpeed100GPerLane(speed, protocol));
+}
+
 string linkWidthMaskToStr(u_int32_t width)
 {
     string widthStr = "";
@@ -1459,6 +1469,110 @@ string linkWidthMaskToStr(u_int32_t width)
     return widthStr;
 }
 
+string getBDFStr(u_int32_t bdf)
+{
+    char bdfBuff[128];
+
+    snprintf(
+      bdfBuff, sizeof(bdfBuff), "%02x:%02x.%x", (u_int8_t)(bdf >> 8), (u_int8_t)(bdf >> 3) & 0x1f, (u_int8_t)(bdf)&7);
+
+    return string(bdfBuff);
+}
+
+int getBDFInt(const string& bdfStr)
+{
+    u_int32_t bdf = 0;
+    try
+    {
+        auto pfStr = MlxlinkRecord::split(bdfStr, ":");
+        size_t sz;
+
+        // make sure that there is one ":" symbol
+        if (pfStr.size() != 2)
+        {
+            return -1;
+        }
+
+        // parse the port function par xx:00.0, split the sec
+        auto funcStr = MlxlinkRecord::split(pfStr[1], ".");
+
+        // make sure that there it's matching this format xx:xx.x
+        if (pfStr[0].size() > 2 || pfStr[1].size() > 4 || funcStr.size() != 2)
+        {
+            return -1;
+        }
+
+        // append 0x to work with hex format only
+        pfStr[0] = "0x" + pfStr[0];
+        pfStr[1] = "0x" + pfStr[1];
+
+        // parse the main pcie function 00:xx.x
+        bdf = stoi(pfStr[0], &sz, 16);
+        bdf <<= 8;
+        if (sz != pfStr[0].size())
+        {
+            return -1;
+        }
+
+        u_int32_t tmp = stoi(funcStr[0], &sz, 16);
+        tmp <<= 3;
+        bdf |= tmp;
+        if (sz != funcStr[0].size())
+        {
+            return -1;
+        }
+
+        // get the function number
+        bdf |= stoi(funcStr[1], &sz, 0);
+        if (sz != funcStr[1].size())
+        {
+            return -1;
+        }
+    }
+    catch (const exception& exp)
+    {
+        return -1;
+    }
+
+    return bdf;
+}
+
+size_t LevStrMatch(const string& source, const string& target)
+{
+    const size_t srcLen = source.size();
+    const size_t trgLen = target.size();
+    size_t idx = 0;
+
+    if (srcLen == 0)
+        return trgLen;
+    if (trgLen == 0)
+        return srcLen;
+
+    vector<size_t> costs(trgLen + 1);
+
+    for (idx = 0; idx < costs.size(); idx++)
+    {
+        costs[idx] = idx;
+    }
+
+    idx = 0;
+    for (auto srcChar : source)
+    {
+        costs[0] = idx + 1;
+        size_t corner = idx;
+        size_t jdx = 0;
+        for (auto trgChar : target)
+        {
+            size_t upper = costs[jdx + 1];
+            costs[jdx + 1] = (srcChar == trgChar) ? corner : 1 + min(min(upper, corner), costs[jdx]);
+            corner = upper;
+            ++jdx;
+        }
+        ++idx;
+    }
+    return costs[trgLen];
+}
+
 bool askUser(const char* question, bool force)
 {
     if (MlxlinkRecord::jsonFormat && force)
