@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2013-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -51,10 +51,11 @@
  * Size: 32 bits
  * Description: reg_tlv */
 
-struct reg_tlv {
-    u_int16_t reserved0;      /* bit_offset:0 */    /* element_size: 16 */
-    u_int16_t len;      /* bit_offset:16 */    /* element_size: 11 */
-    u_int8_t Type;       /* bit_offset:27 */    /* element_size: 5 */    /* TX - 0, RX - ignore */
+struct reg_tlv
+{
+    u_int16_t reserved0; /* bit_offset:0 */                  /* element_size: 16 */
+    u_int16_t len; /* bit_offset:16 */                       /* element_size: 11 */
+    u_int8_t Type; /* bit_offset:27 */ /* element_size: 5 */ /* TX - 0, RX - ignore */
 };
 
 /*************************************/
@@ -62,17 +63,18 @@ struct reg_tlv {
  * Size: 128 bits
  * Description:  */
 
-struct OperationTlv {
-    u_int8_t reserved0;       /* bit_offset:0 */    /* element_size: 8 */
-    u_int8_t status;       /* bit_offset:8 */    /* element_size: 7 */
-    u_int8_t dr;       /* bit_offset:15 */    /* element_size: 1 */
-    u_int16_t len;      /* bit_offset:16 */    /* element_size: 11 */
-    u_int8_t Type;       /* bit_offset:27 */    /* element_size: 5 */    /* TX - 0, RX - ignore */
-    u_int8_t class;       /* bit_offset:32 */    /* element_size: 8 */
-    u_int8_t method;       /* bit_offset:40 */    /* element_size: 7 */
-    u_int8_t r;       /* bit_offset:47 */    /* element_size: 1 */
-    u_int16_t register_id;      /* bit_offset:48 */    /* element_size: 16 */
-    u_int64_t tid;      /* bit_offset:64 */    /* element_size: 64 */
+struct OperationTlv
+{
+    u_int8_t reserved0; /* bit_offset:0 */                   /* element_size: 8 */
+    u_int8_t status; /* bit_offset:8 */                      /* element_size: 7 */
+    u_int8_t dr; /* bit_offset:15 */                         /* element_size: 1 */
+    u_int16_t len; /* bit_offset:16 */                       /* element_size: 11 */
+    u_int8_t Type; /* bit_offset:27 */ /* element_size: 5 */ /* TX - 0, RX - ignore */
+    u_int8_t class; /* bit_offset:32 */                      /* element_size: 8 */
+    u_int8_t method; /* bit_offset:40 */                     /* element_size: 7 */
+    u_int8_t r; /* bit_offset:47 */                          /* element_size: 1 */
+    u_int16_t register_id; /* bit_offset:48 */               /* element_size: 16 */
+    u_int64_t tid; /* bit_offset:64 */                       /* element_size: 64 */
 };
 
 /*************************************/
@@ -80,20 +82,17 @@ struct OperationTlv {
  * Size: 32 bits
  * Description: reg_tlv */
 
-u_int32_t reg_tlv_pack(struct reg_tlv *data_to_pack, u_int8_t *packed_buffer);
-void reg_tlv_unpack(struct reg_tlv *unpacked_data, u_int8_t *buffer_to_unpack);
-void reg_tlv_dump(struct reg_tlv *data_to_print, FILE *out_port);
-
-
+u_int32_t reg_tlv_pack(struct reg_tlv* data_to_pack, u_int8_t* packed_buffer);
+void reg_tlv_unpack(struct reg_tlv* unpacked_data, u_int8_t* buffer_to_unpack);
+void reg_tlv_dump(struct reg_tlv* data_to_print, FILE* out_port);
 
 /*************************************/
 /* Name: OperationTlv
  * Size: 128 bits
  * Description:  */
 
-u_int32_t OperationTlv_pack(struct OperationTlv *data_to_pack, u_int8_t *packed_buffer);
-void OperationTlv_unpack(struct OperationTlv *unpacked_data, u_int8_t *buffer_to_unpack);
-void OperationTlv_dump(struct OperationTlv *data_to_print, FILE *out_port);
-
+u_int32_t OperationTlv_pack(struct OperationTlv* data_to_pack, u_int8_t* packed_buffer);
+void OperationTlv_unpack(struct OperationTlv* unpacked_data, u_int8_t* buffer_to_unpack);
+void OperationTlv_dump(struct OperationTlv* data_to_print, FILE* out_port);
 
 #endif /* internal_packets_functions_H */
