@@ -36,6 +36,10 @@ import sys
 import platform
 import ctypes
 import mtcr
+import struct
+from ctypes import memset
+from regaccess_hca_ext_structs import *
+from regaccess_switch_ext_structs import *
 
 
 def ones(n):
@@ -82,178 +86,8 @@ if REG_ACCESS:
         REG_ACCESS_FAILED_TO_AQUIRE_OWNERSHIP = 1
         REG_ACCESS_NO_OWNERSHIP_REQUIRED = 2
 
-    class RES_DUMP_ST(Structure):
-        _fields_ = [
-            ("segment_type", c_uint16),
-            ("seq_num", c_uint8),
-            ("vhca_id_valid", c_uint8),
-            ("inline_dump", c_uint8),
-            ("more_dump", c_uint8),
-            ("vhca_id", c_uint16),
-            ("index_1", c_uint32),
-            ("index_2", c_uint32),
-            ("num_of_obj_2", c_uint16),
-            ("num_of_obj_1", c_uint16),
-            ("device_opaque", c_uint64),
-            ("mkey", c_uint32),
-            ("size", c_uint32),
-            ("address", c_uint64),
-            ("inline_data", c_uint32 * 52)
-        ]
-
-    class DIAGNOSTIC_CNTR_ST(Structure):
-        _fields_ = [
-            ("counter_id", c_uint16),
-            ("sync", c_uint8)
-        ]
-
-    class DIAGNOSTIC_CNTR_ST_ARR(Array):
-        _type_ = DIAGNOSTIC_CNTR_ST
-        _length_ = 10
-
-    class PCNR_ST(Structure):
-        _fields_ = [
-            ("tuning_override", c_uint8),
-            ("local_port", c_uint8)
-        ]
-
-    class MFRL_ST(Structure):
-        _fields_ = [
-            ("reset_trigger", c_uint8),
-            ("reset_type", c_uint8),
-            ("rst_type_sel", c_uint8),
-            ("pci_sync_for_fw_update_resp", c_uint8),
-            ("pci_sync_for_fw_update_start", c_uint8),
-            ("pci_rescan_required", c_uint8)
-        ]
-
-    class MPCIR_ST(Structure):
-        _fields_ = [
-            ("all", c_uint8),
-            ("ports", c_uint8),
-            ("ports_stat", c_uint8)
-        ]
-
-    class MCAM_REG_ST(Structure):
-        _fields_ = [("access_reg_group", c_uint8),
-                    ("feature_group", c_uint8),
-                    ("mng_access_reg_cap_mask", c_uint32 * 4),
-                    ("mng_feature_cap_mask", c_uint32 * 4)]
-
-    class MTRC_CAP_REG_ST(Structure):
-        _fields_ = [("num_string_db", c_uint8),
-                    ("trc_ver", c_uint8),
-                    ("trace_to_memory", c_uint8),
-                    ("trace_owner", c_uint8),
-                    ("num_string_trace", c_uint8),
-                    ("first_string_trace", c_uint8),
-                    ("log_max_trace_buffer_size", c_uint8),
-                    ("reg_access_hca_string_db_parameters", c_uint8 * 64)]
-
-    class MGIR_ST(Structure):
-        _fields_ = [("device_id", c_uint16),
-                    ("device_hw_revision", c_uint16),
-                    ("pvs", c_uint8),
-                    ("technology", c_uint8),
-                    ("num_ports", c_uint8),
-                    ("hw_dev_id", c_uint16),
-                    ("manufacturing_base_mac_47_32", c_uint16),
-                    ("manufacturing_base_mac_31_0", c_uint32),
-                    ("uptime", c_uint32),
-                    ("sub_minor", c_uint8),
-                    ("minor", c_uint8),
-                    ("major", c_uint8),
-                    ("secure_fw", c_uint8),
-                    ("signed_fw", c_uint8),
-                    ("debug_fw", c_uint8),
-                    ("dev_fw", c_uint8),
-                    ("string_tlv", c_uint8),
-                    ("latency_tlv", c_uint8),
-                    ("dev_sc", c_uint8),
-                    ("build_id", c_uint32),
-                    ("year", c_uint16),
-                    ("day", c_uint8),
-                    ("month", c_uint8),
-                    ("hour", c_uint16),
-                    ("psid", c_uint8 * 16),
-                    ("ini_file_version", c_uint32),
-                    ("extended_major", c_uint32),
-                    ("extended_minor", c_uint32),
-                    ("extended_sub_minor", c_uint32),
-                    ("isfu_major", c_uint16),
-                    ("disabled_tiles_bitmap", c_uint16),
-                    ("life_cycle", c_uint8),
-                    ("sec_boot", c_uint8),
-                    ("encryption", c_uint8),
-                    ("fw_subminor", c_uint8),
-                    ("fw_minor", c_uint8),
-                    ("fw_major", c_uint8),
-                    ("rom3_type", c_uint8),
-                    ("rom3_arch", c_uint8),
-                    ("rom2_type", c_uint8),
-                    ("rom2_arch", c_uint8),
-                    ("rom1_type", c_uint8),
-                    ("rom1_arch", c_uint8),
-                    ("rom0_type", c_uint8),
-                    ("rom0_arch", c_uint8),
-                    ("rom0_version", c_uint32),
-                    ("rom1_version", c_uint32),
-                    ("rom2_version", c_uint32),
-                    ("rom3_version", c_uint32),
-                    ("dev_branch_tag", c_uint8 * 28)]
-
-    class MDDQ_SLOT_INFO(Structure):
-        _fields_ = [("active", c_uint8),
-                    ("lc_ready", c_uint8),
-                    ("sr_valid", c_uint8),
-                    ("provisioned", c_uint8),
-                    ("ini_file_version", c_uint16),
-                    ("hw_revision", c_uint16),
-                    ("card_type", c_uint8)]
-
-    class MDDQ_DEVICE_INFO(Structure):
-        _fields_ = [("device_index", c_uint8),
-                    ("flash_id", c_uint8),
-                    ("lc_pwr_on", c_uint8),
-                    ("thermal_sd", c_uint8),
-                    ("flash_owner", c_uint8),
-                    ("uses_flash", c_uint8),
-                    ("device_type", c_uint16),
-                    ("fw_major", c_uint16),
-                    ("fw_sub_minor", c_uint16),
-                    ("fw_minor", c_uint16),
-                    ("max_cmd_write_size_supp", c_uint8),
-                    ("max_cmd_read_size_supp", c_uint8),
-                    ("device_type_name", c_uint8 * 8)]
-
-    class MDDQ_SLOT_NAME(Structure):
-        _fields_ = [("slot_ascii_name", c_uint8 * 20)]
-
-    class MDDQ_DATA_UN(Union):
-        _fields_ = [("slot_info_ext", MDDQ_SLOT_INFO),
-                    ("device_info_ext", MDDQ_DEVICE_INFO),
-                    ("slot_name_ext", MDDQ_SLOT_NAME)]
-
-    class MDDQ_ST(Structure):
-        _fields_ = [("slot_index", c_uint8),
-                    ("query_type", c_uint8),
-                    ("sie", c_uint8),
-                    ("request_message_sequence", c_uint8),
-                    ("response_message_sequence", c_uint8),
-                    ("query_index", c_uint8),
-                    ("data_valid", c_uint8),
-                    ("data", MDDQ_DATA_UN)]
-
-    class MDSR(Structure):
-        _fields_ = [("status", c_uint8),
-                    ("additional_info", c_uint8),
-                    ("type_of_token", c_uint8),
-                    ("end", c_uint8),
-                    ("time_left", c_uint32)]
 
 
-    class MRSR_ST(Structure):
-        _fields_ = [("command", c_uint8),]
     class RegAccess:
         GET = REG_ACCESS_METHOD_GET
         SET = REG_ACCESS_METHOD_SET
@@ -265,15 +99,22 @@ if REG_ACCESS:
                 self._mstDev = mtcr.MstDevice(pci_device)
             self._reg_access_mcam = REG_ACCESS.reg_access_mcam
             self._reg_access_mtrc_cap = REG_ACCESS.reg_access_mtrc_cap
+            self._reg_access_mtrc_stdb_warpper = REG_ACCESS.reg_access_mtrc_stdb_wrapper
             self._reg_access_mgir = REG_ACCESS.reg_access_mgir
             self._reg_access_mfrl = REG_ACCESS.reg_access_mfrl
             self._reg_access_pcnr = REG_ACCESS.reg_access_pcnr
             self._reg_access_mpcir = REG_ACCESS.reg_access_mpcir
             self._reg_access_res_dump = REG_ACCESS.reg_access_res_dump
-            self._reg_access_debug_cap = None
+            self._reg_access_debug_cap = REG_ACCESS.reg_access_debug_cap
             self._reg_access_mddq = REG_ACCESS.reg_access_mddq
             self._reg_access_mdsr = REG_ACCESS.reg_access_mdsr
+            self._reg_access_mteim = REG_ACCESS.reg_access_mteim
+            self._reg_access_nic_dpa_eug = REG_ACCESS.reg_access_nic_dpa_eug
+            self._reg_access_nic_cap_ext = REG_ACCESS.reg_access_nic_cap_ext
+            self._reg_access_nic_dpa_perf_ctrl = REG_ACCESS.reg_access_nic_dpa_perf_ctrl
             self._reg_access_mrsr = REG_ACCESS.reg_access_mrsr
+            self._reg_access_dtor = REG_ACCESS.reg_access_dtor
+            self._reg_access_mrsi = REG_ACCESS.reg_access_mrsi
 
         def _err2str(self, rc):
             err2str = REG_ACCESS.reg_access_err2str
@@ -290,7 +131,7 @@ if REG_ACCESS:
                 self.close()
 
         def isCsTokenApplied(self):
-            mdsrRegP = pointer(MDSR())
+            mdsrRegP = pointer(MDSR_REG_EXT())
             mdsrRegP.contents.type_of_token == 0  # index for CS token (changed on PRM 0.58)
             rc = self._reg_access_mdsr(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mdsrRegP)
             if rc:
@@ -300,7 +141,7 @@ if REG_ACCESS:
 
         def sendMtrcCapTakeOwnership(self):
 
-            mcamRegP = pointer(MCAM_REG_ST())
+            mcamRegP = pointer(MCAM_REG_EXT())
             rc = self._reg_access_mcam(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mcamRegP)
             if rc:
                 # in case of failure to get capability assume taking ownership is not required, same as in mlxtrace.
@@ -309,8 +150,15 @@ if REG_ACCESS:
             if mtcrCapSupported == 0:
                 return ownershipEnum.REG_ACCESS_NO_OWNERSHIP_REQUIRED
 
+            mtrcaCapRegisterPquery = pointer(MTRC_CAP_REG_EXT())
+            rc = self._reg_access_mtrc_cap(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mtrcaCapRegisterPquery)
+            if rc:
+                raise RegAccException("Failed to send Register MTRC (case 1): %s (%d)" % (self._err2str(rc), rc))
+            if mtrcaCapRegisterPquery.contents.trace_owner == 1:
+                return 0  # already have ownership from last run
+
             maxIterations = 30
-            mtrcaCapRegisterP = pointer(MTRC_CAP_REG_ST())
+            mtrcaCapRegisterP = pointer(MTRC_CAP_REG_EXT())
 
             iter = 0
             while iter < maxIterations:
@@ -319,7 +167,7 @@ if REG_ACCESS:
                 if rc:
                     raise RegAccException("Failed to send Register MTRC (case 2): %s (%d)" % (self._err2str(rc), rc))
                 mtrcaCapRegisterP.contents.trace_owner = c_uint8(0)
-                mtrcaCapRegisterPquery = pointer(MTRC_CAP_REG_ST())
+                mtrcaCapRegisterPquery = pointer(MTRC_CAP_REG_EXT())
                 rc = self._reg_access_mtrc_cap(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mtrcaCapRegisterPquery)
                 if rc:
                     raise RegAccException("Failed to send Register MTRC (case 3): %s (%d)" % (self._err2str(rc), rc))
@@ -327,18 +175,33 @@ if REG_ACCESS:
                     return 0
                 iter += 1
 
+        def sendMtrcCapReleaseOwnership(self):
+            mcamRegP = pointer(MCAM_REG_EXT())
+            rc = self._reg_access_mcam(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mcamRegP)
+            if rc:
+                # in case of failure to get capability assume taking ownership is not required, same as in mlxtrace.
+                return ownershipEnum.REG_ACCESS_NO_OWNERSHIP_REQUIRED
+            mtcrCapSupported = extractField(mcamRegP.contents.mng_access_reg_cap_mask[3 - 2], 0, 1)
+            if mtcrCapSupported == 0:
+                return ownershipEnum.REG_ACCESS_NO_OWNERSHIP_REQUIRED
+
+            mtrcaCapRegisterP = pointer(MTRC_CAP_REG_EXT())
+            mtrcaCapRegisterP.contents.trace_owner = c_uint8(0)
+            self._reg_access_mtrc_cap(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_SET), mtrcaCapRegisterP)
+            return 0
+
         def sendResDump(self, segment_type, seq_num, inline_mode, more_dump, vhca_id, vhca_id_valid, index1, index2, num_of_obj2, num_of_obj1, device_opaque, mkey, size, address):
-            resDumpRegP = pointer(RES_DUMP_ST())
+            resDumpRegP = pointer(RESOURCE_DUMP_EXT())
             resDumpRegP.contents.segment_type = c_uint16(segment_type)
             resDumpRegP.contents.seq_num = c_uint8(seq_num)
             resDumpRegP.contents.inline_dump = c_uint8(inline_mode)
             resDumpRegP.contents.more_dump = c_uint8(more_dump)
             resDumpRegP.contents.vhca_id = c_uint16(vhca_id)
             resDumpRegP.contents.vhca_id_valid = c_uint8(vhca_id_valid)
-            resDumpRegP.contents.index_1 = c_uint32(index1)
-            resDumpRegP.contents.index_2 = c_uint32(index2)
-            resDumpRegP.contents.num_of_obj_2 = c_uint16(num_of_obj2)
-            resDumpRegP.contents.num_of_obj_1 = c_uint16(num_of_obj1)
+            resDumpRegP.contents.index1 = c_uint32(index1)
+            resDumpRegP.contents.index2 = c_uint32(index2)
+            resDumpRegP.contents.num_of_obj2 = c_uint16(num_of_obj2)
+            resDumpRegP.contents.num_of_obj1 = c_uint16(num_of_obj1)
             resDumpRegP.contents.device_opaque = c_uint64(device_opaque)
             resDumpRegP.contents.mkey = c_uint32(mkey)
             resDumpRegP.contents.size = c_uint32(size)
@@ -353,19 +216,40 @@ if REG_ACCESS:
                      "more_dump": resDumpRegP.contents.more_dump,
                      "vhca_id": resDumpRegP.contents.vhca_id,
                      "vhca_id_valid": resDumpRegP.contents.vhca_id_valid,
-                     "index_1": resDumpRegP.contents.index_1,
-                     "index_2": resDumpRegP.contents.index_2,
-                     "num_of_obj_2": resDumpRegP.contents.num_of_obj_2,
-                     "num_of_obj_1": resDumpRegP.contents.num_of_obj_1,
+                     "index1": resDumpRegP.contents.index1,
+                     "index2": resDumpRegP.contents.index2,
+                     "num_of_obj2": resDumpRegP.contents.num_of_obj2,
+                     "num_of_obj1": resDumpRegP.contents.num_of_obj1,
                      "device_opaque": resDumpRegP.contents.device_opaque,
                      "mkey": resDumpRegP.contents.mkey,
                      "size": resDumpRegP.contents.size,
                      "address": resDumpRegP.contents.address,
                      "inline_data": resDumpRegP.contents.inline_data})
 
+        def sendDebugCap(self):
+            debugCapRegP = pointer(DEBUG_CAP())
+            debugCapRegP.contents.log_max_samples = c_uint8(0)
+            debugCapRegP.contents.resource_dump = c_uint8(0)
+            debugCapRegP.contents.log_cr_dump_to_mem_size = c_uint8(0)
+            debugCapRegP.contents.core_dump_qp = c_uint8(0)
+            debugCapRegP.contents.core_dump_general = c_uint8(0)
+            debugCapRegP.contents.log_min_sample_period = c_uint8(0)
+            debugCapRegP.contents.diag_counter_tracer_dump = c_uint8(0)
+            debugCapRegP.contents.health_mon_rx_activity = c_uint8(0)
+            debugCapRegP.contents.repetitive = c_uint8(0)
+            debugCapRegP.contents.single = c_uint8(0)
+            tmp = pointer(DIAGNOSTIC_CNTR_LAYOUT())
+            tmp.contents.counter_id = c_uint16(0)
+            tmp.contents.sync = c_uint8(0)
+            debugCapRegP.contents.diagnostic_counter = pointer(DIAGNOSTIC_CNTR_ST_ARR())
+            rc = self._reg_access_debug_cap(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), debugCapRegP)
+            if rc:
+                raise RegAccException("Failed to send Register DEBUG CAP with rc: %d" % rc)
+            return debugCapRegP.contents.resource_dump
+
         def sendPcnr(self, tuning_override, local_port):  # Requirments : new FW version + burn with allow_pcnr
 
-            pcnrRegisterP = pointer(PCNR_ST())
+            pcnrRegisterP = pointer(PCNR_REG_EXT())
             pcnrRegisterP.contents.tuning_override = c_uint8(tuning_override)
             pcnrRegisterP.contents.local_port = c_uint8(local_port)
 
@@ -388,7 +272,7 @@ if REG_ACCESS:
             else:
                 raise ValueError("command {0} is illegal".format(command))
 
-            mpcirRegisterP = pointer(MPCIR_ST(ports=command))
+            mpcirRegisterP = pointer(MPCIR_EXT(ports=command))
             rc = self._reg_access_mpcir(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mpcirRegisterP)
             if rc != 0:
                 raise RegAccException("Failed to send Command Register MPCIR")
@@ -397,14 +281,39 @@ if REG_ACCESS:
 
         def sendMRSR(self, command):
 
-            mrsrRegisterP = pointer(MRSR_ST(command=command))
+            mrsrRegisterP = pointer(MRSR_EXT(command=command))
             rc = self._reg_access_mrsr(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_SET), mrsrRegisterP)
             if rc != 0:
                 raise RegAccException("Failed to send Command Register MRSR")
+
+        def getDTOR(self):
+            dtorRegisterP = pointer(DTOR_REG_EXT())
+            rc = self._reg_access_dtor(self._mstDev.mf, REG_ACCESS_METHOD_GET, dtorRegisterP)
+            if rc:
+                raise RegAccException("Failed to send Register DTOR")
+
+            return {
+                "DRIVER_UNLOAD_AND_RESET_TO": dtorRegisterP.contents.DRIVER_UNLOAD_AND_RESET_TO,
+                "PCI_SYNC_UPDATE_TO": dtorRegisterP.contents.PCI_SYNC_UPDATE_TO,
+                "PCIE_TOGGLE_TO": dtorRegisterP.contents.PCIE_TOGGLE_TO
+            }
+
+        def getMRSI(self):
+            mrsiRegisterP = pointer(MRSI_EXT())
+            rc = self._reg_access_mrsi(self._mstDev.mf, REG_ACCESS_METHOD_GET, mrsiRegisterP)
+            if rc:
+                raise RegAccException("Failed to send Register MRSI")
+
+            return {
+                "reset_reason": mrsiRegisterP.contents.reset_reason,
+                "crts": mrsiRegisterP.contents.crts,
+                # "ecos": mrsiRegisterP.contents.ecos    # will be uncommented when regaccess_structs.py will be updated.
+            }
+
         ##########################
         def sendMFRL(self, method, resetLevel=None, reset_type=None, reset_sync=None):
 
-            mfrlRegisterP = pointer(MFRL_ST())
+            mfrlRegisterP = pointer(MFRL_REG_EXT())
 
             if method == REG_ACCESS_METHOD_SET:
                 if resetLevel is None or reset_type is None or reset_sync is None:
@@ -415,19 +324,18 @@ if REG_ACCESS:
 
             c_method = c_uint(method)
             rc = self._reg_access_mfrl(self._mstDev.mf, c_method, mfrlRegisterP)
-            # FW bug first mfrl register might fail
-            if rc:
-                rc = self._reg_access_mfrl(self._mstDev.mf, c_method, mfrlRegisterP)
             if rc:
                 raise RegAccException("Failed to send Register MFRL: %s (%d)" % (self._err2str(rc), rc))
 
             if method == REG_ACCESS_METHOD_GET:
-                return mfrlRegisterP.contents.reset_trigger, mfrlRegisterP.contents.reset_type, mfrlRegisterP.contents.pci_rescan_required
+                return mfrlRegisterP.contents.reset_trigger, mfrlRegisterP.contents.reset_type, mfrlRegisterP.contents.pci_rescan_required, mfrlRegisterP.contents.reset_state
 
         ##########################
-        def getMCAM(self):
+        def getMCAM(self, access_reg_group=0):
+
+            mcamRegP = pointer(MCAM_REG_EXT())
+            mcamRegP.contents.access_reg_group = c_uint8(access_reg_group)
 
-            mcamRegP = pointer(MCAM_REG_ST())
             rc = self._reg_access_mcam(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mcamRegP)
             if rc:
                 raise RegAccException("Failed to send Register MCAM (rc: {0})".format(rc))
@@ -442,76 +350,133 @@ if REG_ACCESS:
         ##########################
         def getFwVersion(self):
 
-            mgirRegisterP = pointer(MGIR_ST())
+            mgirRegisterP = pointer(MGIR_EXT())
 
             rc = self._reg_access_mgir(self._mstDev.mf, REG_ACCESS_METHOD_GET, mgirRegisterP)
             if rc:
                 info_ver = ""
             else:
                 # get dev branch tag
-                info_ver = "".join(chr(val) for val in mgirRegisterP.contents.dev_branch_tag if val != 0)
+                info_ver = "".join(chr(val) for val in mgirRegisterP.contents.dev_info.dev_branch_tag if val != 0)
 
                 # if dev branch is empty, try to get the primary version
                 if info_ver == "":
-                    if mgirRegisterP.contents.fw_major != 0:
-                        info_ver = "{0}.{1}.{2}".format(mgirRegisterP.contents.fw_major,
-                                                        mgirRegisterP.contents.fw_minor,
-                                                        mgirRegisterP.contents.fw_subminor)
-                    elif mgirRegisterP.contents.extended_major != 0:
-                        info_ver = "{0}.{1}.{2}".format(mgirRegisterP.contents.extended_major,
-                                                        mgirRegisterP.contents.extended_minor,
-                                                        mgirRegisterP.contents.extended_sub_minor)
+                    if mgirRegisterP.contents.fw_info.major != 0:
+                        info_ver = "{0}.{1}.{2}".format(mgirRegisterP.contents.fw_info.major,
+                                                        mgirRegisterP.contents.fw_info.minor,
+                                                        mgirRegisterP.contents.fw_info.sub_minor)
+                    elif mgirRegisterP.contents.fw_info.extended_major != 0:
+                        info_ver = "{0}.{1}.{2}".format(mgirRegisterP.contents.fw_info.extended_major,
+                                                        mgirRegisterP.contents.fw_info.extended_minor,
+                                                        mgirRegisterP.contents.fw_info.extended_sub_minor)
 
             return info_ver
 
         def getFWUptime(self):
 
-            mgirRegisterP = pointer(MGIR_ST())
+            mgirRegisterP = pointer(MGIR_EXT())
 
             rc = self._reg_access_mgir(self._mstDev.mf, REG_ACCESS_METHOD_GET, mgirRegisterP)
             if rc:
                 raise RegAccException("Failed to send Register MGIR (case 1): %s (%d)" % (self._err2str(rc), rc))
 
-            return mgirRegisterP.contents.uptime
+            return mgirRegisterP.contents.hw_info.uptime
+
+        def getMtrcCap(self):
+            mcamRegP = pointer(MCAM_REG_EXT())
+            rc = self._reg_access_mcam(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mcamRegP)
+            if rc:
+                # in case of failure to get capability assume taking ownership is not required, same as in mlxtrace.
+                return False
+            mtcrCapSupported = extractField(mcamRegP.contents.mng_access_reg_cap_mask[3 - 2], 0, 1)
+            if mtcrCapSupported == 0:
+                return False
+            mtrcCapRegisterP = pointer(MTRC_CAP_REG_EXT())
+            rc = self._reg_access_mtrc_cap(self._mstDev.mf, REG_ACCESS_METHOD_GET, mtrcCapRegisterP)
+            if rc:
+                raise RegAccException("Failed to send Register Mtrc_Cap (case 1): %s (%d)" % (self._err2str(rc), rc))
+
+            string_db_parameters_list = []
+            for i in range(0, 8):
+                string_db_parameters_list.append(
+                    {
+                        "string_db_base_address": mtrcCapRegisterP.contents.string_db_param[i].string_db_base_address,
+                        "string_db_size": mtrcCapRegisterP.contents.string_db_param[i].string_db_size
+                    }
+                )
+
+            return {
+                "num_string_db": mtrcCapRegisterP.contents.num_string_db,
+                "trc_ver": mtrcCapRegisterP.contents.trc_ver,
+                "trace_to_memory": mtrcCapRegisterP.contents.trace_to_memory,
+                "trace_owner": mtrcCapRegisterP.contents.trace_owner,
+                "num_string_trace": mtrcCapRegisterP.contents.num_string_trace,
+                "first_string_trace": mtrcCapRegisterP.contents.first_string_trace,
+                "log_max_trace_buffer_size": mtrcCapRegisterP.contents.log_max_trace_buffer_size,
+                "string_db_param": string_db_parameters_list,
+            }
+
+        def isMtrcStdbSupported(self):
+            mcamRegP = pointer(MCAM_REG_EXT())
+            rc = self._reg_access_mcam(self._mstDev.mf, c_uint(REG_ACCESS_METHOD_GET), mcamRegP)
+            if rc:
+                # in case of failure to get capability assume taking ownership is not required, same as in mlxtrace.
+                return False
+            mtcrStdbSupported = extractField(mcamRegP.contents.mng_access_reg_cap_mask[3 - 2], 2, 1)
+            if mtcrStdbSupported == 0:
+                return False
+            return True
+
+        def getMtrcStdbStringDbData(self, string_db_index, read_size):
+            c_string_db_index = c_uint8(string_db_index)
+            c_read_size = c_uint32(read_size)
+            byte_buffer = (c_uint8 * read_size)()
+            rc = self._reg_access_mtrc_stdb_warpper(self._mstDev.mf, c_read_size, c_string_db_index, byte_buffer)
+            if rc:
+                raise RegAccException("Failed to send Register Mtrc_Stdb (case 1): {}".format(rc))
+
+            uint32_buffer = ctypes.cast(byte_buffer, ctypes.POINTER(ctypes.c_uint32))
+            data = b"".join([struct.pack('>I', uint32_buffer[i]) for i in range(read_size // 4)])
+            return data
 
         def getManufacturingBaseMac(self):
 
-            mgirRegisterP = pointer(MGIR_ST())
+            mgirRegisterP = pointer(MGIR_EXT())
 
             rc = self._reg_access_mgir(self._mstDev.mf, REG_ACCESS_METHOD_GET, mgirRegisterP)
 
             if rc:
                 raise RegAccException("Failed to send Register MGIR (case 2): %s (%d)" % (self._err2str(rc), rc))
 
-            lsp = mgirRegisterP.contents.manufacturing_base_mac_31_0
-            msp = mgirRegisterP.contents.manufacturing_base_mac_47_32
+            lsp = mgirRegisterP.contents.hw_info.manufacturing_base_mac_31_0
+            msp = mgirRegisterP.contents.hw_info.manufacturing_base_mac_47_32
 
             return msp * (2**32) + lsp
 
         def getSecureFWStatus(self):
             """ Returns True if the FW is secured, False otherwise.
             """
-            mgirRegisterP = pointer(MGIR_ST())
+            mgirRegisterP = pointer(MGIR_EXT())
 
             rc = self._reg_access_mgir(self._mstDev.mf, REG_ACCESS_METHOD_GET, mgirRegisterP)
             if rc:
                 raise RegAccException("Failed to send Register MGIR (case 3): %s (%d)" % (self._err2str(rc), rc))
 
-            result = mgirRegisterP.contents.secure_fw
+            result = mgirRegisterP.contents.fw_info.secured
             result = True if result else False
             return result
 
         def getPSID(self):
-            mgirRegisterP = pointer(MGIR_ST())
+            mgirRegisterP = pointer(MGIR_EXT())
             rc = self._reg_access_mgir(self._mstDev.mf, REG_ACCESS_METHOD_GET, mgirRegisterP)
             if rc:
                 raise RegAccException("Failed to send Register MGIR (case 4): %s (%d)" % (self._err2str(rc), rc))
 
-            psid = "".join(chr(val) for val in mgirRegisterP.contents.psid if val != 0)
+            psid = "".join(chr(val) for val in mgirRegisterP.contents.fw_info.psid if val != 0)
             return psid
 
         def sendMddq(self, query_type, request_message_sequence, slot_index, query_index=0):
-            mddqRegisterP = pointer(MDDQ_ST())
+            mddqRegisterP = pointer(MDDQ_EXT())
             mddqRegisterP.contents.query_type = c_uint8(query_type)
             mddqRegisterP.contents.slot_index = c_uint8(slot_index)
             mddqRegisterP.contents.request_message_sequence = c_uint8(request_message_sequence)
@@ -553,8 +518,29 @@ if REG_ACCESS:
                      "data_valid": mddqRegisterP.contents.data_valid},
                     data)
 
+        def sendMTEIM(self):
+            mteimRegisterP = pointer(MTEIM_REG_EXT())
+            rc = self._reg_access_mteim(self._mstDev.mf, REG_ACCESS_METHOD_GET, mteimRegisterP)
+            if rc:
+                return None  # done raise error, could be old FW / Device
+                #raise RegAccException("Failed to send Register MTEIM: %s (%d)" % (self._err2str(rc), rc))
+
+            return ({"cap_core_tile": mteimRegisterP.contents.cap_core_tile,
+                    "cap_core_main": mteimRegisterP.contents.cap_core_main,
+                     "cap_core_dpa": mteimRegisterP.contents.cap_core_dpa,
+                     "cap_num_of_tile": mteimRegisterP.contents.cap_num_of_tile,
+                     "type_core_tile": mteimRegisterP.contents.type_core_tile,
+                     "type_core_main": mteimRegisterP.contents.type_core_main,
+                     "type_core_dpa": mteimRegisterP.contents.type_core_dpa,
+                     "is_phy_uc_supported": mteimRegisterP.contents.is_phy_uc_supported,
+                     "is_dwsn_msb_supported": mteimRegisterP.contents.is_dwsn_msb_supported,
+                     "first_dpa_core_event_id": mteimRegisterP.contents.first_dpa_core_event_id,
+                     "first_main_core_event_id": mteimRegisterP.contents.first_main_core_event_id,
+                     "first_tile_core_event_id": mteimRegisterP.contents.first_tile_core_event_id
+                     })
+
+
 else:
     raise RegAccException("Failed to load rreg_access.so/libreg_access.dll")
 
-
 ####################################################################################
